@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: components.h 1826 2011-03-12 01:00:56Z ela $
+ * $Id: components.h 1872 2013-03-06 14:13:37Z fransschreuder $
  *
  */
 
@@ -115,6 +115,7 @@
 #include "microstrip/msopen.h"
 #include "microstrip/msgap.h"
 #include "microstrip/mscoupled.h"
+#include "microstrip/mslange.h"
 #include "microstrip/mstee.h"
 #include "microstrip/mscross.h"
 #include "microstrip/msvia.h"
@@ -147,11 +148,16 @@
 #include "verilog/potentiometer.core.h"
 #include "verilog/MESFET.core.h"
 #include "verilog/EKV26MOS.core.h"
+#include "verilog/bsim3v34nMOS.core.h"
+#include "verilog/bsim3v34pMOS.core.h"
+#include "verilog/bsim4v30nMOS.core.h"
+#include "verilog/bsim4v30pMOS.core.h"
 #include "verilog/hicumL0V1p2.core.h"
 #include "verilog/hicumL0V1p2g.core.h"
 #include "verilog/hicumL0V1p3.core.h"
 #include "verilog/hicumL2V2p23.core.h"
 #include "verilog/hicumL2V2p24.core.h"
+#include "verilog/hicumL2V2p31n.core.h" 
 #include "verilog/photodiode.core.h"
 #include "verilog/phototransistor.core.h"
 #include "verilog/nigbt.core.h"
