@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: strafo.cpp 1825 2011-03-11 20:42:14Z ela $
+ * $Id$
  *
  */
 
@@ -104,7 +104,7 @@ void strafo::initAC (void) {
 }
 
 void strafo::initTR (void) {
-  initDC ();
+  initAC ();
 }
 
 // properties
