@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: trafo.cpp 1825 2011-03-11 20:42:14Z ela $
+ * $Id$
  *
  */
 
@@ -70,7 +70,7 @@ void trafo::initAC (void) {
 }
 
 void trafo::initTR (void) {
-  initDC ();
+  initAC ();
 }
 
 // properties
