@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_spice.cpp 1825 2011-03-11 20:42:14Z ela $
+ * $Id$
  *
  */
 
@@ -654,7 +654,9 @@ static void spice_adjust_device (struct definition_t * def,
 	    def->pairs = spice_del_property (def->pairs, p2);
 	    if (level == 0) {
 	      if (version >= 1.11) {
-		if (version >= 1.3)
+		if (version >= 1.2e9)
+		  def->type = strdup ("hicumL0V1p2g");
+		else if (version >= 1.3)
 		  def->type = strdup ("hicumL0V1p3");
 		else if (version >= 1.2)
 		  def->type = strdup ("hicumL0V1p2");
