@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: complex.cpp 1825 2011-03-11 20:42:14Z ela $
+ * $Id$
  *
  */
 
@@ -366,7 +366,7 @@ nr_complex_t atan (const nr_complex_t z) {
    \return arc tangent of z
 */
 nr_complex_t atan2 (const nr_complex_t y, const nr_complex_t x) {
-  nr_complex_t a = atan (y / x);
+  nr_complex_t a = std::tr1::atan (y / x);
   return real (x) > 0.0 ? a : -a;
 }
 #endif
