@@ -2,6 +2,7 @@
  * module.cpp - module class implementation
  *
  * Copyright (C) 2008, 2009, 2010 Stefan Jahn <stefan@lkcc.org>
+ * New models added Mike Brinson 2013 mbrin72043@yahoo.co.uk
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: module.cpp 1826 2011-03-12 01:00:56Z ela $
+ * $Id: module.cpp 1872 2013-03-06 14:13:37Z fransschreuder $
  *
  */
 
@@ -192,6 +193,7 @@ void module::registerModules (void) {
   REGISTER_CIRCUIT (msgap);
   REGISTER_CIRCUIT (msmbend);
   REGISTER_CIRCUIT (mscoupled);
+  REGISTER_CIRCUIT (mslange);  
   REGISTER_CIRCUIT (mstee);
   REGISTER_CIRCUIT (mscross);
   REGISTER_CIRCUIT (msvia);
@@ -236,11 +238,16 @@ void module::registerModules (void) {
   REGISTER_CIRCUIT (potentiometer);
   REGISTER_CIRCUIT (MESFET);
   REGISTER_CIRCUIT (EKV26MOS);
+  REGISTER_CIRCUIT (bsim3v34nMOS);
+  REGISTER_CIRCUIT (bsim3v34pMOS);
+  REGISTER_CIRCUIT (bsim4v30nMOS);
+  REGISTER_CIRCUIT (bsim4v30pMOS);
   REGISTER_CIRCUIT (hicumL0V1p2);
   REGISTER_CIRCUIT (hicumL0V1p2g);
   REGISTER_CIRCUIT (hicumL0V1p3);
   REGISTER_CIRCUIT (hicumL2V2p23);
   REGISTER_CIRCUIT (hicumL2V2p24);
+  REGISTER_CIRCUIT (hicumL2V2p31n); 
   REGISTER_CIRCUIT (photodiode);
   REGISTER_CIRCUIT (phototransistor);
   REGISTER_CIRCUIT (nigbt);
