@@ -21,53 +21,59 @@
 
 #include "qucsedit.h"
 
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qhbox.h>
-#include <qpushbutton.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qmessagebox.h>
-#include <qtoolbutton.h>
-#include <qimage.h>
-#include <qfiledialog.h>
-#include <qfont.h>
-
+#include <QApplication>
+#include <QLabel>
+#include <QPushButton>
+#include <QFile>
+#include <QTextStream>
+#include <QMessageBox>
+#include <QToolButton>
+#include <QImage>
+#include <QFont>
+#include <QPixmap>
+#include <QCloseEvent>
+#include <QToolBar>
+#include <QTextEdit>
+#include <QFileDialog>
+#include <QtGui>
 
 QucsEdit::QucsEdit(const QString& FileName_, bool readOnly)
 {
   // set application icon
-  setIcon (QPixmap(QucsSettings.BitmapDir + "big.qucs.xpm"));
-  setCaption("Qucs Editor " PACKAGE_VERSION " - " + tr("File: "));
+  setWindowIcon (QPixmap(QucsSettings.BitmapDir + "big.qucs.xpm"));
+  setWindowTitle("Qucs Editor " PACKAGE_VERSION " - " + tr("File: "));
 
-  QVBoxLayout *v = new QVBoxLayout(this);
-
-  QHBox *h = new QHBox(this);
-  v->addWidget(h);
-
-  QToolButton *ButtLoad = new QToolButton(h);
-  ButtLoad->setIconSet(
-	    QIconSet(QImage(QucsSettings.BitmapDir + "fileopen.png")));
+  QToolButton *ButtLoad = new QToolButton;
+  ButtLoad->setIcon(QIcon((QucsSettings.BitmapDir + "fileopen.png")));
   connect(ButtLoad, SIGNAL(clicked()), SLOT(slotLoad()));
 
-  QToolButton *ButtSave = new QToolButton(h);
-  ButtSave->setIconSet(
-            QIconSet(QImage(QucsSettings.BitmapDir + "filesave.png")));
+  QToolButton *ButtSave = new QToolButton;
+  ButtSave->setIcon(QIcon((QucsSettings.BitmapDir + "filesave.png")));
   connect(ButtSave, SIGNAL(clicked()), SLOT(slotSave()));
   ButtSave->setDisabled(readOnly);
 
-  h->setStretchFactor(new QWidget(h),5); // stretchable placeholder
-  PosText = new QLabel(tr("Line: %1  -  Column: %2").arg(1).arg(1), h);
-  h->setStretchFactor(new QWidget(h),5); // stretchable placeholder
+  PosText = new QLabel(tr("Line: %1  -  Column: %2").arg(1).arg(1));
 
-  QPushButton *ButtAbout = new QPushButton(tr("About"),h);
+  QPushButton *ButtAbout = new QPushButton(tr("About"));
   connect(ButtAbout, SIGNAL(clicked()), SLOT(slotAbout()));
 
-  QPushButton *ButtOK = new QPushButton(tr("Quit"),h);
+  QPushButton *ButtOK = new QPushButton(tr("Quit"));
   connect(ButtOK, SIGNAL(clicked()), SLOT(slotQuit()));
   ButtOK->setFocus();
 
+  QWidget *separator = new QWidget(this);
+  separator->setSizePolicy(QSizePolicy::Expanding,
+                           QSizePolicy::Expanding);
+
+  QToolBar *tool = addToolBar("main toolbar");
+
+  tool->addWidget(ButtLoad);
+  tool->addWidget(ButtSave);
+  tool->addWidget(separator);
+  tool->addWidget(PosText);
+  tool->addWidget(ButtAbout);
+  tool->addWidget(ButtOK);
+
   // try using same-sized mono-spaced font in the textarea
   QFont fedit = QFont("Courier New");
   fedit.setPointSize(QucsSettings.font.pointSize()-1);
@@ -75,28 +81,27 @@ QucsEdit::QucsEdit(const QString& FileName_, bool readOnly)
   fedit.setFixedPitch(true);
 
   text = new QTextEdit(this);
-  text->setTextFormat(Qt::PlainText);
+  //text->setTextFormat(Qt::PlainText);
   text->setReadOnly(readOnly);
-  text->setWordWrap(QTextEdit::NoWrap);
+  text->setWordWrapMode(QTextOption::NoWrap);
   text->setMinimumSize(300,200);
   text->setFont(fedit);
   text->setCurrentFont(fedit);
-  v->addWidget(text);
-  connect(text, SIGNAL(cursorPositionChanged(int, int)),
-          SLOT(slotPrintCursorPosition(int, int)));
+
+  setCentralWidget(text);
+
+  connect(text, SIGNAL(cursorPositionChanged()),
+          SLOT(slotPrintCursorPosition()));
 
   // .................................................
   loadFile(FileName_);
 }
 
-QucsEdit::~QucsEdit()
-{
-}
-
 // ************************************************************
-void QucsEdit::slotPrintCursorPosition(int Para, int Pos)
+void QucsEdit::slotPrintCursorPosition()
 {
-  PosText->setText(tr("Line: %1  -  Column: %2").arg(Para+1).arg(Pos+1));
+  QTextCursor cursor=text->textCursor();
+  PosText->setText(tr("Line: %1  -  Column: %2").arg(cursor.blockNumber()+1).arg(cursor.columnNumber()+1));
 }
 
 // ************************************************************
@@ -115,10 +120,8 @@ void QucsEdit::slotAbout()
 void QucsEdit::slotLoad()
 {
   static QString lastDir;  // to remember last directory and file
-
-  QString s = QFileDialog::getOpenFileName(
-    lastDir.isEmpty() ? QString(".") : lastDir,
-    "*", this, "", tr("Enter a Filename"));
+  QString s = QFileDialog::getOpenFileName(this, tr("Enter a Filename"),
+                                           lastDir.isEmpty() ? QString(".") : lastDir, "*");
   if(s.isEmpty()) return;
   lastDir = s;   // remember last directory and file
   if(!closeFile()) return;
@@ -129,21 +132,21 @@ void QucsEdit::slotLoad()
 void QucsEdit::slotSave()
 {
   if(FileName.isEmpty()) {
-    FileName = QFileDialog::getSaveFileName(".", QString::null,
-	this, "", tr("Enter a Document Name"));
+    FileName = QFileDialog::getSaveFileName(this, tr("Enter a Document Name"),
+                                            ".", QString::null);
     if(FileName.isEmpty())  return;
   }
 
   QFile file(FileName);
-  if(!file.open(IO_WriteOnly)) {
+  if(!file.open(QIODevice::WriteOnly)) {
     QMessageBox::critical(this, tr("Error"),
 		tr("Cannot write file: ")+FileName);
     return;
   }
 
   QTextStream stream(&file);
-  stream << text->text();
-  text->setModified(false);
+  stream << text->toPlainText();
+  text->document()->setModified(false);
   file.close();
 }
 
@@ -158,7 +161,8 @@ void QucsEdit::slotQuit()
   tmp = width();	// dialog !!!  Otherwise the frame of the window ...
   tmp = height();	// will not be recognized (a X11 problem).
 
-  accept();
+  qApp->quit();
+
 }
 
 // ************************************************************
@@ -173,20 +177,18 @@ bool QucsEdit::loadFile(const QString& Name)
 {
   if(Name.isEmpty()) return false;
   QFile file(Name);
-  if(!file.open(IO_ReadOnly)) {
+  if(!file.open(QIODevice::ReadOnly)) {
     QMessageBox::critical(this, tr("Error"),
 		tr("Cannot read file: ")+Name);
     return false;
   }
 
   QTextStream stream(&file);
-  text->setText(stream.read());
+  text->document()->setPlainText(stream.readAll());
   file.close();
 
   FileName = Name;
-//  QFileInfo info(Name);
-//  FileName = info.fileName();
-  setCaption("Qucs Editor " PACKAGE_VERSION " - " + tr("File: ")+FileName);
+  setWindowTitle("Qucs Editor " PACKAGE_VERSION " - " + tr("File: ")+FileName);
   return true;
 }
 
@@ -194,7 +196,7 @@ bool QucsEdit::loadFile(const QString& Name)
 // ************************************************************
 bool QucsEdit::closeFile()
 {
-  if(text->isModified()) {
+  if(text->document()->isModified()) {
     switch(QMessageBox::warning(this,tr("Closing document"),
       tr("The text contains unsaved changes!\n")+
       tr("Do you want to save the changes?"),
