@@ -18,7 +18,10 @@
 #ifndef QUCSEDIT_H
 #define QUCSEDIT_H
 
-#include <qdialog.h>
+#include <QMainWindow>
+#include <QApplication>
+#include <QCloseEvent>
+#include <QLabel>
 
 class QLabel;
 class QTextEdit;
@@ -35,18 +38,17 @@ struct tQucsSettings {
 extern tQucsSettings QucsSettings;
 
 
-class QucsEdit : public QDialog  {
+class QucsEdit : public QMainWindow  {
    Q_OBJECT
 public:
   QucsEdit(const QString&, bool readOnly=false);
- ~QucsEdit();
 
 private slots:
   void slotAbout();
   void slotLoad();
   void slotSave();
   void slotQuit();
-  void slotPrintCursorPosition(int, int);
+  void slotPrintCursorPosition();
 
 private:
   void closeEvent(QCloseEvent*);
