@@ -18,7 +18,8 @@
 #ifndef QUCSFILTER_H
 #define QUCSFILTER_H
 
-#include <qdialog.h>
+#include <QDialog>
+#include <QLabel>
 
 class QGridLayout;
 class QComboBox;
