@@ -18,19 +18,18 @@
 #ifndef QUCSLIB_H
 #define QUCSLIB_H
 
-#include <qdialog.h>
-#include <qdir.h>
-#include <qfont.h>
-#include <qstring.h>
-#include <qstringlist.h>
+#include <QMainWindow>
+#include <QDir>
+#include <QFont>
+#include <QString>
+#include <QStringList>
+#include <QTextEdit>
+#include <QCloseEvent>
+#include <QListWidgetItem>
+#include <QVBoxLayout>
+#include <QComboBox>
 
-class SymbolWidget;
-class QTextEdit;
-class QComboBox;
-class QListBox;
-class QVGroupBox;
-class QVBoxLayout;
-class QListBoxItem;
+#include "symbolwidget.h"
 
 
 // Application settings.
@@ -46,16 +45,16 @@ struct tQucsSettings {
 extern tQucsSettings QucsSettings;
 extern QDir UserLibDir;
 
-class QucsLib : public QDialog  {
+class QucsLib : public QMainWindow  {
    Q_OBJECT
 public:
   QucsLib();
- ~QucsLib();
+  ~QucsLib();
 
-  QListBox     *CompList;
+  QListWidget *CompList;
   QStringList   LibraryComps;
   QComboBox    *Library;
-  QString       DefaultSymbol;
+  QString DefaultSymbol;
 
 private slots:
   void slotAbout();
@@ -65,7 +64,7 @@ private slots:
   void slotShowModel();
   void slotSelectLibrary(int);
   void slotSearchComponent();
-  void slotShowComponent(QListBoxItem*);
+  void slotShowComponent(QListWidgetItem*);
   void slotManageLib();
 
 private:
@@ -73,12 +72,14 @@ private:
   void putLibrariesIntoCombobox();
   bool getSection(QString, QString &, QString &);
 
+  QMenu *fileMenu, *helpMenu;
+
   int UserLibCount;
   SymbolWidget *Symbol;
   QTextEdit    *CompDescr;
   QVBoxLayout  *all;
-
   QDir QucsHomeDir;  // Qucs user directory where all projects are located
+
 };
 
 #endif /* QUCSLIB_H */
