@@ -18,15 +18,17 @@
 #ifndef SYMBOLWIDGET_H
 #define SYMBOLWIDGET_H
 
-#include <qwidget.h>
-#include <qsize.h>
-#include <qpen.h>
-#include <qbrush.h>
-#include <qcolor.h>
-#include <qstring.h>
-#include <qptrlist.h>
+#include <QWidget>
+#include <QSize>
+#include <QPen>
+#include <QBrush>
+#include <QColor>
+#include <QString>
+#include <QList>
+#include <QMouseEvent>
+#include <QPaintEvent>
+
 
-class QDragObject;
 class QPaintEvent;
 class QSizePolicy;
 
@@ -74,7 +76,7 @@ public:
  ~SymbolWidget();
 
   QString theModel();
-  int setSymbol(const QString&, const QString&, const QString&);
+  int setSymbol( QString&, const QString&, const QString&);
   int createSymbol(const QString&, const QString&);
 
   // component properties
@@ -94,15 +96,20 @@ private:
   bool getPen  (const QString&, QPen&, int);
   bool getBrush(const QString&, QBrush&, int);
 
-  QDragObject *myDragObject;
+  //Q3DragObject *myDragObject;
+
 
   QString PaintText, DragNDropText;
   int TextWidth, DragNDropWidth, TextHeight;
   int cx, cy, x1, x2, y1, y2;
-  QPtrList<Line>       Lines;
-  QPtrList<struct Arc> Arcs;
-  QPtrList<Area>       Rects, Ellips;
-  QPtrList<Text>       Texts;
+  QList<Line *> Lines;
+  QList<Arc *> Arcs;
+  QList<Area *> Rects, Ellips;
+  QList<Text *>  Texts;
+  //Q3PtrList<Line>       Lines;
+  //Q3PtrList<struct Arc> Arcs;
+  //Q3PtrList<Area>       Rects, Ellips;
+  //Q3PtrList<Text>       Texts;
 };
 
 #endif
