@@ -18,22 +18,28 @@
 #ifndef QUCSTRANS_H
 #define QUCSTRANS_H
 
-#include <qdialog.h>
-#include <qfont.h>
-#include <qstring.h>
+#include <QDialog>
+#include <QFont>
+#include <QString>
+#include <QGridLayout>
+#include <QTextStream>
+#include <QVBoxLayout>
+#include <QLabel>
+#include <QCloseEvent>
+#include <QMainWindow>
+
 
 class QComboBox;
 class QLineEdit;
 class QLabel;
-class QHGroupBox;
-class QVBox;
+class QGroupBox;
 class QVBoxLayout;
 class QRadioButton;
 class QGridLayout;
 class QStatusBar;
 class QTextStream;
 class QButtonGroup;
-class QWidgetStack;
+class QStackedWidget;
 
 class transline;
 
@@ -81,7 +87,6 @@ struct TransValue {
   QLineEdit * lineedit;  // Qt value widget
   QComboBox * combobox;  // Qt unit widget
   QRadioButton * radio;  // Qt fixed widget
-  QWidgetStack * stack;  // Qt fixed stack
 };
 
 // Array of transmission line values.
@@ -128,7 +133,7 @@ struct TransUnit {
   *@author Stefan Jahn
   */
 
-class QucsTranscalc : public QDialog  {
+class QucsTranscalc : public QMainWindow  {
    Q_OBJECT
 public:
   QucsTranscalc();
@@ -164,12 +169,12 @@ private slots:
 
 private:
   void updateSelection ();
-  void createPropItem (QVBox **, TransValue *, int, QButtonGroup *);
-  void createResultItem (QVBox **, TransResult *);
+  void createPropItem (QGridLayout *, TransValue *, int, QButtonGroup *);
+  void createResultItem (QGridLayout *, TransResult *);
   void updateResultItem (TransResult *);
-  void createResultItems (QHGroupBox *);
+  void createResultItems (QGroupBox *);
   void updateResultItems ();
-  void createPropItems (QHGroupBox *, int);
+  void createPropItems (QGroupBox *, int);
   int getTypeIndex ();
   void updatePropItem (TransValue *);
   void setMode (int);
@@ -187,7 +192,7 @@ private:
   QStatusBar * statBar;
   QLabel * pix;
   QComboBox * tranType;
-  QHGroupBox * calculated;
+  QGroupBox * calculated;
   int mode;
 };
 
