@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include "circulator.h"
 #include "main.h"
 
@@ -23,16 +23,16 @@ Circulator::Circulator()
 {
   Description = QObject::tr("circulator");
 
-  Arcs.append(new Arc(-14,-14, 28, 28,  0,16*360,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-30,  0,-14,  0,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 30,  0, 14,  0,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(  0, 14,  0, 30,QPen(QPen::darkBlue,2)));
+  Arcs.append(new Arc(-14,-14, 28, 28,  0,16*360,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-30,  0,-14,  0,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 30,  0, 14,  0,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(  0, 14,  0, 30,QPen(Qt::darkBlue,2)));
 
-  Arcs.append(new Arc( -8, -6, 16, 16,16*20,16*150,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(  8,  0,  9, -7,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(  8,  0,  2, -1,QPen(QPen::darkBlue,2)));
+  Arcs.append(new Arc( -8, -6, 16, 16,16*20,16*150,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(  8,  0,  9, -7,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(  8,  0,  2, -1,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(-22, -4,-26,  4,QPen(QPen::darkBlue,2)));   // marks port 1
+  Lines.append(new Line(-22, -4,-26,  4,QPen(Qt::darkBlue,2)));   // marks port 1
 
   Ports.append(new Port(-30,  0));
   Ports.append(new Port( 30,  0));
