@@ -65,6 +65,7 @@
 #include "substrate.h"
 #include "msline.h"
 #include "mscoupled.h"
+#include "mslange.h"
 #include "msstep.h"
 #include "mscorner.h"
 #include "mstee.h"
@@ -146,11 +147,16 @@
 #include "potentiometer.h"
 #include "MESFET.h"
 #include "EKV26MOS.h"
+#include "bsim3v34nMOS.h"
+#include "bsim3v34pMOS.h"
+#include "bsim4v30nMOS.h"
+#include "bsim4v30pMOS.h"
 #include "hicumL0V1p2.h"
 #include "hicumL0V1p2g.h"
 #include "hicumL0V1p3.h"
 #include "hicumL2V2p23.h"
 #include "hicumL2V2p24.h"
+#include "hicumL2V2p31n.h" 
 #include "photodiode.h"
 #include "phototransistor.h"
 #include "nigbt.h"
