@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include "d_flipflop.h"
 #include "node.h"
 #include "main.h"
@@ -26,21 +26,21 @@ D_FlipFlop::D_FlipFlop()
 
   Props.append(new Property("t", "0", false, QObject::tr("delay time")));
 
-  Lines.append(new Line(-20,-20, 20,-20,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-20, 20, 20, 20,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-20,-20,-20, 20,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 20,-20, 20, 20,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-20,-20, 20,-20,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-20, 20, 20, 20,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-20,-20,-20, 20,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 20,-20, 20, 20,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(-30,-10,-20,-10,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-30, 10,-20, 10,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 30,-10, 20,-10,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(  0, 20,  0, 30,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-30,-10,-20,-10,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-30, 10,-20, 10,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 30,-10, 20,-10,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(  0, 20,  0, 30,QPen(Qt::darkBlue,2)));
 
-  Texts.append(new Text(-18,-21, "D", QPen::darkBlue, 12.0));
-  Texts.append(new Text(  6,-21, "Q", QPen::darkBlue, 12.0));
-  Texts.append(new Text( -4,  4, "R", QPen::darkBlue, 9.0));
-  Lines.append(new Line(-20,  6,-12, 10,QPen(QPen::darkBlue,0)));
-  Lines.append(new Line(-20, 14,-12, 10,QPen(QPen::darkBlue,0)));
+  Texts.append(new Text(-18,-21, "D", Qt::darkBlue, 12.0));
+  Texts.append(new Text(  6,-21, "Q", Qt::darkBlue, 12.0));
+  Texts.append(new Text( -4,  4, "R", Qt::darkBlue, 9.0));
+  Lines.append(new Line(-20,  6,-12, 10,QPen(Qt::darkBlue,0)));
+  Lines.append(new Line(-20, 14,-12, 10,QPen(Qt::darkBlue,0)));
 
   Ports.append(new Port(-30,-10));  // D
   Ports.append(new Port(-30, 10));  // Clock
