@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include "digi_source.h"
 #include "main.h"
 #include "node.h"
@@ -25,18 +25,18 @@ Digi_Source::Digi_Source()
   Type = isComponent;   // both analog and digital
   Description = QObject::tr("digital source");
 
-  Lines.append(new Line(-10,  0,  0,  0,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-20,-10,-10,  0,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-20, 10,-10,  0,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-35,-10,-20,-10,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-35, 10,-20, 10,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-35,-10,-35, 10,QPen(QPen::darkGreen,2)));
+  Lines.append(new Line(-10,  0,  0,  0,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-20,-10,-10,  0,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-20, 10,-10,  0,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-35,-10,-20,-10,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-35, 10,-20, 10,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-35,-10,-35, 10,QPen(Qt::darkGreen,2)));
 
-  Lines.append(new Line(-32, 5,-28, 5,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-28,-5,-24,-5,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-24, 5,-20, 5,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-28,-5,-28, 5,QPen(QPen::darkGreen,2)));
-  Lines.append(new Line(-24,-5,-24, 5,QPen(QPen::darkGreen,2)));
+  Lines.append(new Line(-32, 5,-28, 5,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-28,-5,-24,-5,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-24, 5,-20, 5,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-28,-5,-28, 5,QPen(Qt::darkGreen,2)));
+  Lines.append(new Line(-24,-5,-24, 5,QPen(Qt::darkGreen,2)));
 
   Ports.append(new Port(  0,  0));
 
@@ -111,12 +111,12 @@ QString Digi_Source::vhdlCode(int NumPorts)
   int z = 0;
   char State;
   if(NumPorts <= 0) {  // time table simulation ?
-    if(Props.at(1)->Value == "low")
+    if(Props.at(0)->Value == "low")
       State = '0';
     else
       State = '1';
 
-    t = Props.next()->Value.section(';',z,z).stripWhiteSpace();
+    t = Props.at(2)->Value.section(';',z,z).stripWhiteSpace();
     while(!t.isEmpty()) {
       s += Out + State + "';";    // next value for signal
 
@@ -126,12 +126,12 @@ QString Digi_Source::vhdlCode(int NumPorts)
       s += t.replace("after","wait for") + ";\n";
       State ^= 1;
       z++;
-      t = Props.current()->Value.section(';',z,z).stripWhiteSpace();
+      t = Props.at(2)->Value.section(';',z,z).stripWhiteSpace();
     }
   }
   else {  // truth table simulation
     State = '0';
-    int Num = Props.getFirst()->Value.toInt() - 1;
+    int Num = Props.at(0)->Value.toInt() - 1;
     
     s += Out + State + "';";    // first value for signal
     s += "  wait for "+QString::number(1 << Num)+" ns;\n";
