@@ -75,22 +75,22 @@ Element * mod_amp::info(QString& Name, char * &BitmapFile, bool getNewOne)
 void mod_amp::createSymbol()
 {
 
-  Lines.append(new Line(-30,-20,-20,-20,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-30, 20,-20, 20,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 30,  0, 40,  0,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-30,-20,-20,-20,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-30, 20,-20, 20,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 30,  0, 40,  0,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(-20,-35,-20, 35,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-20,-35, 30,  0,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-20, 35, 30,  0,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-20,-35,-20, 35,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-20,-35, 30,  0,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-20, 35, 30,  0,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(-16, 19, -9, 19,QPen(QPen::black,2)));
-  Lines.append(new Line(-16,-19, -9,-19,QPen(QPen::red,2)));
-  Lines.append(new Line(-13,-22,-13,-15,QPen(QPen::red,2)));
+  Lines.append(new Line(-16, 19, -9, 19,QPen(Qt::black,2)));
+  Lines.append(new Line(-16,-19, -9,-19,QPen(Qt::red,2)));
+  Lines.append(new Line(-13,-22,-13,-15,QPen(Qt::red,2)));
 
-  Lines.append(new Line(-10, -10, -10, 10,QPen(QPen::red,2)));
-  Lines.append(new Line(-10, -10,  0,   0,QPen(QPen::red,2)));
-  Lines.append(new Line(  0,  0,  10, -10,QPen(QPen::red,2)));
-  Lines.append(new Line( 10, -10, 10,  10,QPen(QPen::red,2)));
+  Lines.append(new Line(-10, -10, -10, 10,QPen(Qt::red,2)));
+  Lines.append(new Line(-10, -10,  0,   0,QPen(Qt::red,2)));
+  Lines.append(new Line(  0,  0,  10, -10,QPen(Qt::red,2)));
+  Lines.append(new Line( 10, -10, 10,  10,QPen(Qt::red,2)));
   
   Ports.append(new Port(-30,-20));
   Ports.append(new Port(-30, 20));
