@@ -18,9 +18,11 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-
+#include <QtGui>
 #include "subcircuit.h"
 #include "qucs.h"
+//Added by qt3to4:
+#include <Q3TextStream>
 #include "schematic.h"
 #include "main.h"
 
@@ -105,22 +107,22 @@ void Subcircuit::createSymbol()
 void Subcircuit::remakeSymbol(int No)
 {
   int h = 30*((No-1)/2) + 15;
-  Lines.append(new Line(-15, -h, 15, -h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 15, -h, 15,  h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-15,  h, 15,  h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-15, -h,-15,  h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-15, -h, 15, -h,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 15, -h, 15,  h,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-15,  h, 15,  h,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-15, -h,-15,  h,QPen(Qt::darkBlue,2)));
   Texts.append(new Text(-10, -6,"sub"));
 
   int i=0, y = 15-h;
   while(i<No) {
     i++;
-    Lines.append(new Line(-30,  y,-15,  y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line(-30,  y,-15,  y,QPen(Qt::darkBlue,2)));
     Ports.append(new Port(-30,  y));
     Texts.append(new Text(-25,y-14,QString::number(i)));
 
     if(i == No) break;
     i++;
-    Lines.append(new Line( 15,  y, 30,  y,QPen(QPen::darkBlue,2)));
+    Lines.append(new Line( 15,  y, 30,  y,QPen(Qt::darkBlue,2)));
     Ports.append(new Port( 30,  y));
     Texts.append(new Text( 19,y-14,QString::number(i)));
     y += 60;
@@ -138,17 +140,17 @@ void Subcircuit::remakeSymbol(int No)
 int Subcircuit::loadSymbol(const QString& DocName)
 {
   QFile file(DocName);
-  if(!file.open(IO_ReadOnly))
+  if(!file.open(QIODevice::ReadOnly))
     return -1;
 
   QString Line;
   // *****************************************************************
   // To strongly speed up the file read operation the whole file is
   // read into the memory in one piece.
-  QTextStream ReadWhole(&file);
+  Q3TextStream ReadWhole(&file);
   QString FileString = ReadWhole.read();
   file.close();
-  QTextStream stream(&FileString, IO_ReadOnly);
+  Q3TextStream stream(&FileString, QIODevice::ReadOnly);
 
 
   // read header **************************
