@@ -19,6 +19,8 @@
 #define VERILOGFILE_H
 
 #include "component.h"
+//Added by qt3to4:
+#include <Q3TextStream>
 
 
 class Verilog_File : public MultiViewComponent  {
