@@ -18,7 +18,7 @@
 #if HAVE_CONFIG_H
 # include <config.h>
 #endif
-
+#include <QtGui>
 #include <stdlib.h>
 #include <math.h>
 #include <float.h>
@@ -27,15 +27,18 @@
 #endif
 #include <locale.h>
 
-#include <qtextstream.h>
+#include <q3textstream.h>
 #include <qmessagebox.h>
 #include <qregexp.h>
 #include <qdatetime.h>
+//Added by qt3to4:
+#include <Q3CString>
 
 #include "diagram.h"
 #include "qucs.h"
 #include "main.h"
 #include "mnemo.h"
+#include "schematic.h"
 
 #include "rect3ddiagram.h"
 
@@ -51,7 +54,7 @@ static double strtod_faster (char * pPos, char ** pEnd) {
     (*pEnd)++;
   if ((**pEnd == 'j') || (**pEnd == 'i'))
     (*pEnd)--;
-  QCString str = QCString (pPos, *pEnd - pPos + 1);
+  Q3CString str = Q3CString (pPos, *pEnd - pPos + 1);
   bool ok;
   double x = str.toDouble (&ok);
   if (!ok) *pEnd = pPos;
@@ -91,7 +94,7 @@ Diagram::Diagram(int _cx, int _cy)
 
   Type = isDiagram;
   isSelected = false;
-  GridPen = QPen(QPen::lightGray,0);
+  GridPen = QPen(Qt::lightGray,0);
   Graphs.setAutoDelete(true);
   Arcs.setAutoDelete(true);
   Lines.setAutoDelete(true);
@@ -125,10 +128,10 @@ void Diagram::paint(ViewPainter *p)
 
 
   // write whole text (axis label inclusively)
-  QWMatrix wm = p->Painter->worldMatrix();
+  QMatrix wm = p->Painter->worldMatrix();
   for(Text *pt = Texts.first(); pt != 0; pt = Texts.next()) {
     p->Painter->setWorldMatrix(
-        QWMatrix(pt->mCos, -pt->mSin, pt->mSin, pt->mCos,
+        QMatrix(pt->mCos, -pt->mSin, pt->mSin, pt->mCos,
                  p->DX + float(cx+pt->x) * p->Scale,
                  p->DY + float(cy-pt->y) * p->Scale));
 
@@ -151,9 +154,9 @@ void Diagram::paint(ViewPainter *p)
     fx_ = float(x2)*p->Scale + 10;
     fy_ = float(y2)*p->Scale + 10;
 
-    p->Painter->setPen(QPen(QPen::darkGray,3));
+    p->Painter->setPen(QPen(Qt::darkGray,3));
     p->Painter->drawRect(x_-5, y_-5, TO_INT(fx_), TO_INT(fy_));
-    p->Painter->setPen(QPen(QPen::darkRed,2));
+    p->Painter->setPen(QPen(Qt::darkRed,2));
     p->drawResizeRect(cx, cy-y2);  // markers for changing the size
     p->drawResizeRect(cx, cy);
     p->drawResizeRect(cx+x2, cy-y2);
@@ -162,9 +165,9 @@ void Diagram::paint(ViewPainter *p)
 }
 
 // ------------------------------------------------------------
-void Diagram::paintScheme(QPainter *p)
+void Diagram::paintScheme(Schematic *p)
 {
-  p->drawRect(cx, cy-y2, x2, y2);
+  p->PostPaintEvent(_Rect, cx, cy-y2, x2, y2);
 }
 
 // ------------------------------------------------------------
@@ -174,7 +177,7 @@ void Diagram::createAxisLabels()
   Graph *pg;
   int   x, y, w, wmax = 0;
   QString Str;
-  QFontMetrics  metrics(QucsSettings.font);
+  QFontMetrics  metrics(((Schematic*)QucsMain->DocumentTab->currentPage())->font());   // get size of text
   int LineSpacing = metrics.lineSpacing();
 
 
@@ -879,7 +882,7 @@ int Diagram::loadVarData(const QString& fileName, Graph *g)
       return 0;  // digital variables only for tabulars and ziming diagram
 
 
-  if(!file.open(IO_ReadOnly))  return 0;
+  if(!file.open(QIODevice::ReadOnly))  return 0;
 
   // *****************************************************************
   // To strongly speed up the file read operation the whole file is
@@ -1169,14 +1172,15 @@ bool Diagram::sameDependencies(Graph *g1, Graph *g2)
 int Diagram::checkColumnWidth(const QString& Str,
 		const QFontMetrics& metrics, int colWidth, int x, int y)
 {
-  int w = metrics.width(Str);  // width of text
+    //qDebug("%i", metrics.charWidth(Str,0));
+  int w = metrics.boundingRect(Str).width();  // width of text
   if(w > colWidth) {
     colWidth = w;
     if((x+colWidth) >= x2) {    // enough space for text ?
       // mark lack of space with a small arrow
-      Lines.append(new Line(x2-6, y-4, x2+7, y-4, QPen(QPen::red,2)));
-      Lines.append(new Line(x2,   y-7, x2+6, y-4, QPen(QPen::red,2)));
-      Lines.append(new Line(x2,   y-1, x2+6, y-4, QPen(QPen::red,2)));
+      Lines.append(new Line(x2-6, y-4, x2+7, y-4, QPen(Qt::red,2)));
+      Lines.append(new Line(x2,   y-7, x2+6, y-4, QPen(Qt::red,2)));
+      Lines.append(new Line(x2,   y-1, x2+6, y-4, QPen(Qt::red,2)));
       return -1;
     }
   }
@@ -1254,7 +1258,7 @@ QString Diagram::save()
 }
 
 // ------------------------------------------------------------
-bool Diagram::load(const QString& Line, QTextStream *stream)
+bool Diagram::load(const QString& Line, Q3TextStream *stream)
 {
   bool ok;
   QString s = Line;
@@ -1544,7 +1548,7 @@ void Diagram::createSmithChart(Axis *Axis, int Mode)
   if(Axis->up > 1.0) {  // draw circle with |r|=1 ?
     x = (x2-R1) >> 1;
     y = (x2+R1) >> 1;
-    Arcs.append(new struct Arc(x, y, R1, R1, beta, theta, QPen(QPen::black,0)));
+    Arcs.append(new struct Arc(x, y, R1, R1, beta, theta, QPen(Qt::black,0)));
 
     // vertical line Re(r)=1 (visible only if |r|>1)
     if(Zplane)  x = y;
@@ -1658,9 +1662,9 @@ void Diagram::createPolarDiagram(Axis *Axis, int Mode)
   phi = int(16.0*180.0/M_PI*atan(double(2*tHeight)/double(x2)));
   if(!Below)  tmp = phi;
   else  tmp = 0;
-  Arcs.append(new struct Arc(0, y2, x2, y2, tmp, 16*360-phi, QPen(QPen::black,0)));
+  Arcs.append(new struct Arc(0, y2, x2, y2, tmp, 16*360-phi, QPen(Qt::black,0)));
 
-  QFontMetrics  metrics(QucsSettings.font);
+  QFontMetrics  metrics(((Schematic*)QucsMain->DocumentTab->currentPage())->font());   // get size of text
   QSize r = metrics.size(0, Texts.current()->s);  // width of text
   len = x2+r.width()-4;   // more space at the right
   if(len > x3)  x3 = len;
@@ -1891,7 +1895,7 @@ bool Diagram::calcYAxis(Axis *Axis, int x0)
   double GridStep, corr, zD, zDstep, GridNum;
 
   QString tmp;
-  QFontMetrics  metrics(QucsSettings.font);
+  QFontMetrics  metrics(((Schematic*)QucsMain->DocumentTab->currentPage())->font());   // get size of text
   int maxWidth = 0;
 
   bool back = false;
@@ -1920,7 +1924,7 @@ if(Axis->log) {
         Texts.append(new Text(-w-7, z-6, tmp)); // text aligned right
 
       // y marks
-      Lines.append(new Line(x0-5, z, x0+5, z, QPen(QPen::black,0)));
+      Lines.append(new Line(x0-5, z, x0+5, z, QPen(Qt::black,0)));
     }
 
     zD += zDstep;
@@ -1956,7 +1960,7 @@ else {  // not logarithmical
 
     if(Axis->GridOn)  if(z < y2)  if(z > 0)
       Lines.prepend(new Line(0, z, x2, z, GridPen));  // y grid
-    Lines.append(new Line(x0-5, z, x0+5, z, QPen(QPen::black,0))); // y marks
+    Lines.append(new Line(x0-5, z, x0+5, z, QPen(Qt::black,0))); // y marks
     zD += zDstep;
     z = int(zD);
   }
