@@ -18,7 +18,7 @@
 #if HAVE_CONFIG_H
 # include <config.h>
 #endif
-
+#include <QtGui>
 #include <math.h>
 #include <float.h>
 #ifdef __MINGW32__
@@ -32,6 +32,8 @@
 
 #include "rectdiagram.h"
 #include "main.h"
+#include "qucs.h"
+#include "schematic.h"
 
 
 RectDiagram::RectDiagram(int _cx, int _cy) : Diagram(_cx, _cy)
@@ -125,7 +127,7 @@ int RectDiagram::calcDiagram()
   Arcs.clear();
 
   double GridStep, corr, zD, zDstep, GridNum;
-  QFontMetrics  metrics(QucsSettings.font);
+  QFontMetrics  metrics(((Schematic*)QucsMain->DocumentTab->currentPage())->font());   // get size of text
   y1 = QucsSettings.font.pointSize() + 6;
 
   x1 = 10;      // position of label text
@@ -168,7 +170,7 @@ if(xAxis.log) {
       w = metrics.width(tmp);  // width of text
 
       Texts.append(new Text(z-(w>>1), -y1, tmp));
-      Lines.append(new Line(z, 5, z, -5, QPen(QPen::black,0)));  // x marks
+      Lines.append(new Line(z, 5, z, -5, QPen(Qt::black,0)));  // x marks
     }
 
     zD += zDstep;
@@ -199,7 +201,7 @@ else {  // not logarithmical
 
     if(xAxis.GridOn)  if(z < x2)  if(z > 0)
       Lines.prepend(new Line(z, y2, z, 0, GridPen)); // x grid
-    Lines.append(new Line(z, 5, z, -5, QPen(QPen::black,0)));   // x marks
+    Lines.append(new Line(z, 5, z, -5, QPen(Qt::black,0)));   // x marks
     zD += zDstep;
     z = int(zD);
   }
@@ -213,10 +215,10 @@ else {  // not logarithmical
 
 Frame:
   // outer frame
-  Lines.append(new Line(0,  y2, x2, y2, QPen(QPen::black,0)));
-  Lines.append(new Line(x2, y2, x2,  0, QPen(QPen::black,0)));
-  Lines.append(new Line(0,   0, x2,  0, QPen(QPen::black,0)));
-  Lines.append(new Line(0,  y2,  0,  0, QPen(QPen::black,0)));
+  Lines.append(new Line(0,  y2, x2, y2, QPen(Qt::black,0)));
+  Lines.append(new Line(x2, y2, x2,  0, QPen(Qt::black,0)));
+  Lines.append(new Line(0,   0, x2,  0, QPen(Qt::black,0)));
+  Lines.append(new Line(0,  y2,  0,  0, QPen(Qt::black,0)));
   return valid;
 }
 
