@@ -18,7 +18,7 @@
 #if HAVE_CONFIG_H
 # include <config.h>
 #endif
-
+#include <QtGui>
 #include <math.h>
 #include <float.h>
 #ifdef __MINGW32__
@@ -43,7 +43,7 @@ SmithDiagram::SmithDiagram(int _cx, int _cy, bool ImpMode) : Diagram(_cx, _cy)
   if(ImpMode)  Name = "Smith";  // with impedance circles
   else  Name = "ySmith";        // with admittance circles
 
-  Arcs.append(new struct Arc(0, y2, x2, y2, 0, 16*360, QPen(QPen::black,0)));
+  Arcs.append(new struct Arc(0, y2, x2, y2, 0, 16*360, QPen(Qt::black,0)));
 //  calcDiagram();    // calculate circles for smith chart with |r|=1
 }
 
@@ -91,7 +91,7 @@ int SmithDiagram::calcDiagram()
   else  createSmithChart(&yAxis);
 
   // outer most circle
-  Arcs.append(new Arc(0, x2, x2, x2, 0, 16*360, QPen(QPen::black,0)));
+  Arcs.append(new Arc(0, x2, x2, x2, 0, 16*360, QPen(Qt::black,0)));
 
   // horizontal line Im(r)=0
   Lines.append(new Line(0, x2>>1, x2, x2>>1, GridPen));
