@@ -18,8 +18,10 @@
 #ifndef IMPORTDIALOG_H
 #define IMPORTDIALOG_H
 
-#include <qdialog.h>
-#include <qprocess.h>
+#include <QDialog>
+#include <QProcess>
+#include <QGridLayout>
+#include <QLabel>
 
 class QTextEdit;
 class QLineEdit;
@@ -38,7 +40,7 @@ public:
 private slots:
   void slotDisplayMsg();
   void slotDisplayErr();
-  void slotProcessEnded();
+  void slotProcessEnded(int status);
   void slotImport();
   void slotAbort();
   void slotBrowse();
