@@ -14,54 +14,54 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include "labeldialog.h"
 #include "../wirelabel.h"
 
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qvalidator.h>
+#include <QLabel>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QValidator>
+#include <QGridLayout>
 
 
 LabelDialog::LabelDialog(WireLabel *pl, QWidget *parent)
-                     : QDialog(parent, 0, true)
+                     : QDialog(parent) //, 0, true)
 {
-  setCaption(tr("Insert Nodename"));
+  setWindowTitle(tr("Insert Nodename"));
 
   pLabel = pl;
-  gbox = new QGridLayout(this,4,3,5,5);
+  gbox = new QGridLayout(this);
 
   // valid expression for LineEdit: alpha-numeric, but must start with
   // letter and never two "_" together
   Expr1.setPattern("[a-zA-Z]([0-9a-zA-Z]|_(?!_))+\\!{0,1}");
-  Validator1 = new QRegExpValidator(Expr1, this);
+  Validator1 = new QRegExpValidator(Expr1);
 
-  QLabel *Label1 = new QLabel(tr("Enter the label:"),this);
+  QLabel *Label1 = new QLabel(tr("Enter the label:"));
   gbox->addWidget(Label1,0,0);
 
-  NodeName = new QLineEdit(this);
+  NodeName = new QLineEdit();
   if(pLabel)  NodeName->setText(pLabel->Name);
   NodeName->setValidator(Validator1);
-  gbox->addMultiCellWidget(NodeName,1,1,0,3);
+  gbox->addWidget(NodeName,1,0,1,3);
 
   Expr2.setPattern("[^\"=]+");    // valid expression for LineEdit
-  Validator2 = new QRegExpValidator(Expr2, this);
+  Validator2 = new QRegExpValidator(Expr2);
 
-  Label2 = new QLabel(tr("Initial node voltage:"),this);
+  Label2 = new QLabel(tr("Initial node voltage:"));
   gbox->addWidget(Label2,2,0);
-  InitValue = new QLineEdit(this);
+  InitValue = new QLineEdit();
   if(pLabel)  InitValue->setText(pLabel->initValue);
   InitValue->setValidator(Validator2);
-  gbox->addMultiCellWidget(InitValue,2,2,1,3);
+  gbox->addWidget(InitValue,2,1,1,2);
 
-  ButtonMore = new QPushButton(tr("Less..."),this);
-  gbox->addWidget(ButtonMore,3,1);
-  ButtonOk = new QPushButton(tr("Ok"),this);
-  gbox->addWidget(ButtonOk,3,2);
-  ButtonCancel = new QPushButton(tr("Cancel"),this);
-  gbox->addWidget(ButtonCancel,3,3);
+  ButtonMore = new QPushButton(tr("Less..."));
+  gbox->addWidget(ButtonMore,3,0);
+  ButtonOk = new QPushButton(tr("Ok"));
+  gbox->addWidget(ButtonOk,3,1);
+  ButtonCancel = new QPushButton(tr("Cancel"));
+  gbox->addWidget(ButtonCancel,3,2);
 
   for(;;) {
     if(pLabel)  if(!pLabel->initValue.isEmpty())  break;
