@@ -18,7 +18,8 @@
 #ifndef NEWPROJDIALOG_H
 #define NEWPROJDIALOG_H
 
-#include <qdialog.h>
+#include <QDialog>
+#include <QGridLayout>
 
 class QLineEdit;
 class QCheckBox;
