@@ -20,12 +20,13 @@
 
 #include "qucs.h"
 
-#include <qdialog.h>
-#include <qfont.h>
-#include <qregexp.h>
+#include <QDialog>
+#include <QFont>
+#include <QRegExp>
+#include <QVBoxLayout>
 
 class QListView;
-class QListViewItem;
+//class Q3ListViewItem;
 class QLineEdit;
 class QCheckBox;
 class QVBoxLayout;
@@ -33,7 +34,8 @@ class QPushButton;
 class QComboBox;
 class QIntValidator;
 class QRegExpValidator;
-
+class QTableView;
+class QStandardItemModel;
 
 class QucsSettingsDialog : public QDialog  {
    Q_OBJECT
@@ -49,7 +51,6 @@ private slots:
   void slotDefaultValues();
   void slotAdd();
   void slotRemove();
-  void slotEditSuffix(QListViewItem*);
   void slotColorComment();
   void slotColorString();
   void slotColorInteger();
@@ -59,6 +60,7 @@ private slots:
   void slotColorAttribute();
   void slotColorDirective();
   void slotColorTask();
+  void slotTableCliked(int,int);
 
 public:
   QucsApp *App;
@@ -68,7 +70,8 @@ public:
   QComboBox *LanguageCombo;
   QPushButton *FontButton, *BGColorButton;
   QLineEdit *undoNumEdit, *editorEdit, *Input_Suffix, *Input_Program;
-  QListView *List_Suffix;
+  QTableWidget *tableWidget;
+  QStandardItemModel *model;
   QPushButton *ColorComment, *ColorString, *ColorInteger,
        *ColorReal, *ColorCharacter, *ColorDataType, *ColorAttribute,
        *ColorDirective, *ColorTask;
