@@ -18,7 +18,8 @@
 #ifndef SETTINGSDIALOG_H
 #define SETTINGSDIALOG_H
 
-#include <qdialog.h>
+#include <QDialog>
+#include <QVBoxLayout>
 
 class Schematic;
 class QLineEdit;
