@@ -14,20 +14,21 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include <stdlib.h>
-
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qvgroupbox.h>
-#include <qhgroupbox.h>
-#include <qhbox.h>
-#include <qtimer.h>
-#include <qpushbutton.h>
-#include <qprogressbar.h>
-#include <qtextedit.h>
-#include <qdatetime.h>
-#include <qregexp.h>
+#include <iostream>
+using namespace std;
+#include <QLabel>
+#include <QGroupBox>
+#include <QTimer>
+#include <QPushButton>
+#include <QTextEdit>
+#include <QDateTime>
+#include <QRegExp>
+#include <QTextStream>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QProcess>
 
 #include "simmessage.h"
 #include "main.h"
@@ -37,11 +38,17 @@
 #include "components/opt_sim.h"
 #include "components/vhdlfile.h"
 
+#ifdef __MINGW32__
+#define executablePostfix ".exe"
+#else
+#define executablePostfix ""
+#endif
+
 
 SimMessage::SimMessage(QWidget *w, QWidget *parent)
-		: QDialog(parent, 0, FALSE, Qt::WDestructiveClose)
+		: QDialog(parent) //, 0, FALSE, Qt::WDestructiveClose)
 {
-  setCaption(tr("Qucs Simulation Messages"));
+  setWindowTitle(tr("Qucs Simulation Messages"));
   QucsDoc *Doc;
   DocWidget = w;
   if(DocWidget->inherits("QTextEdit"))
@@ -62,47 +69,59 @@ SimMessage::SimMessage(QWidget *w, QWidget *parent)
   all = new QVBoxLayout(this);
   all->setSpacing(5);
   all->setMargin(5);
-  QVGroupBox *Group1 = new QVGroupBox(tr("Progress:"),this);
+  QGroupBox *Group1 = new QGroupBox(tr("Progress:"));
   all->addWidget(Group1);
+  QVBoxLayout *vbox1 = new QVBoxLayout();
+  Group1->setLayout(vbox1);
 
-  ProgText = new QTextEdit(Group1);
+  ProgText = new QTextEdit();
+  vbox1->addWidget(ProgText);
   ProgText->setTextFormat(Qt::PlainText);
   ProgText->setReadOnly(true);
-  ProgText->setWordWrap(QTextEdit::NoWrap);
+  //ProgText->setWordWrapMode(QTextOption::NoWrap);
   ProgText->setMinimumSize(400,80);
   wasLF = false;
 
-  QHGroupBox *HGroup = new QHGroupBox(this);
-  HGroup->setInsideMargin(5);
-  HGroup->setInsideSpacing(5);
+  QGroupBox *HGroup = new QGroupBox();
+  QHBoxLayout *hbox = new QHBoxLayout();
+  //HGroup->setInsideMargin(5);
+  //HGroup->setInsideSpacing(5);
   all->addWidget(HGroup);
-  new QLabel(tr("Progress:"), HGroup);
-  SimProgress = new QProgressBar(HGroup);
+  QLabel *progr = new QLabel(tr("Progress:"));
+  hbox->addWidget(progr);
+  SimProgress = new QProgressBar();
+  hbox->addWidget(SimProgress);
 //  SimProgress->setPercentageVisible(false);
+  HGroup->setLayout(hbox);
 
-  QVGroupBox *Group2 = new QVGroupBox(tr("Errors and Warnings:"),this);
+  QGroupBox *Group2 = new QGroupBox(tr("Errors and Warnings:"));
   all->addWidget(Group2);
+  QVBoxLayout *vbox2 = new QVBoxLayout();
 
-  ErrText = new QTextEdit(Group2);
+  ErrText = new QTextEdit();
+  vbox2->addWidget(ErrText);
   ErrText->setTextFormat(Qt::PlainText);
   ErrText->setReadOnly(true);
-  ErrText->setWordWrap(QTextEdit::NoWrap);
+  ErrText->setWordWrapMode(QTextOption::NoWrap);
   ErrText->setMinimumSize(400,80);
+  Group2->setLayout(vbox2);
 
-  QHBox *Butts = new QHBox(this);
-  all->addWidget(Butts);
+  QHBoxLayout *Butts = new QHBoxLayout();
+  all->addLayout(Butts);
 
-  Display = new QPushButton(tr("Goto display page"), Butts);
+  Display = new QPushButton(tr("Goto display page"));
+  Butts->addWidget(Display);
   Display->setDisabled(true);
   connect(Display,SIGNAL(clicked()),SLOT(slotDisplayButton()));
 
-  Abort = new QPushButton(tr("Abort simulation"), Butts);
+  Abort = new QPushButton(tr("Abort simulation"));
+  Butts->addWidget(Abort);
   connect(Abort,SIGNAL(clicked()),SLOT(reject()));
 }
 
 SimMessage::~SimMessage()
 {
-  if(SimProcess.isRunning())  SimProcess.kill();
+  if(SimProcess.Running)  SimProcess.kill();
   delete all;
 }
 
@@ -116,18 +135,20 @@ bool SimMessage::startProcess()
     arg(QDate::currentDate().toString("ddd dd. MMM yyyy")).
     arg(QTime::currentTime().toString("hh:mm:ss"));
   ProgText->insert(txt + "\n\n");
-
+  
   SimProcess.blockSignals(false);
-  if(SimProcess.isRunning()) {
+ /* On Qt4 it shows as running even before we .start it. FIXME
+  if(SimProcess.Running) {
+    qDebug() << "running!";  
     ErrText->insert(tr("ERROR: Simulator is still running!"));
     FinishSimulation(-1);
     return false;
   }
-
+*/
   Collect.clear();  // clear list for NodeSets, SPICE components etc.
   ProgText->insert(tr("creating netlist... "));
   NetlistFile.setName(QucsHomeDir.filePath("netlist.txt"));
-   if(!NetlistFile.open(IO_WriteOnly)) {
+   if(!NetlistFile.open(QIODevice::WriteOnly)) {
     ErrText->insert(tr("ERROR: Cannot write netlist file!"));
     FinishSimulation(-1);
     return false;
@@ -140,6 +161,7 @@ bool SimMessage::startProcess()
        ((Schematic*)DocWidget)->prepareNetlist(Stream, Collect, ErrText);
     if(SimPorts < -5) {
       NetlistFile.close();
+      ErrText->insert(tr("ERROR: Cannot simulate a text file!"));
       FinishSimulation(-1);
       return false;
     }
@@ -148,12 +170,12 @@ bool SimMessage::startProcess()
 
 
   disconnect(&SimProcess, 0, 0, 0);
-  connect(&SimProcess, SIGNAL(readyReadStderr()), SLOT(slotDisplayErr()));
-  connect(&SimProcess, SIGNAL(readyReadStdout()),
+  connect(&SimProcess, SIGNAL(readyReadStandardError()), SLOT(slotDisplayErr()));
+  connect(&SimProcess, SIGNAL(readyReadStandardOutput()),
                        SLOT(slotReadSpiceNetlist()));
-  connect(&SimProcess, SIGNAL(processExited()),
-                       SLOT(slotFinishSpiceNetlist()));
-
+  connect(&SimProcess, SIGNAL(finished(int)),
+                       SLOT(slotFinishSpiceNetlist(int)));
+ 
   nextSPICE();
   return true;
   // Since now, the Doc pointer may be obsolete, as the user could have
@@ -163,7 +185,7 @@ bool SimMessage::startProcess()
 // ---------------------------------------------------
 // Converts a spice netlist into Qucs format and outputs it.
 void SimMessage::nextSPICE()
-{
+{ 
   QString Line;
   for(;;) {  // search for next SPICE component
     Line = *(Collect.begin());
@@ -172,6 +194,8 @@ void SimMessage::nextSPICE()
       startSimulator(); // <<<<<================== go on ===
       return;
     }
+#warning SPICE section below not being covered?
+    qDebug() << "goin thru SPICE branch on simmmessage.cpp";
     if(Line.left(5) == "SPICE") {
       if(Line.at(5) != 'o') insertSim = true;
       else insertSim = false;
@@ -186,25 +210,24 @@ void SimMessage::nextSPICE()
   if(Line.isEmpty())  makeSubcircuit = false;
   else  makeSubcircuit = true;
 
+  QString prog;
   QStringList com;
-  com << (QucsSettings.BinDir + "qucsconv");
+  prog = QucsSettings.BinDir + "qucsconv";
   if(makeSubcircuit)
     com << "-g" << "_ref";
   com << "-if" << "spice" << "-of" << "qucs";
-  SimProcess.setArguments(com);
 
   QFile SpiceFile;
   if(FileName.find(QDir::separator()) < 0)  // add path ?
     SpiceFile.setName(QucsWorkDir.path() + QDir::separator() + FileName);
   else
     SpiceFile.setName(FileName);
-  if(!SpiceFile.open(IO_ReadOnly)) {
+  if(!SpiceFile.open(QIODevice::ReadOnly)) {
     ErrText->insert(tr("ERROR: Cannot open SPICE file \"%1\".").arg(FileName));
     FinishSimulation(-1);
     return;
   }
 
-
   if(makeSubcircuit) {
     Stream << "\n.Def:" << properName(FileName) << " ";
   
@@ -214,9 +237,12 @@ void SimMessage::nextSPICE()
   }
   Stream << "\n";
 
-
   ProgressText = "";
-  if(!SimProcess.start()) {
+  
+  qDebug() << "start QucsConv" << prog << com.join(" ");
+  SimProcess.start(prog, com);
+  
+  if(!SimProcess.Running) {
     ErrText->insert(tr("ERROR: Cannot start QucsConv!"));
     FinishSimulation(-1);
     return;
@@ -224,14 +250,16 @@ void SimMessage::nextSPICE()
 
   QByteArray SpiceContent = SpiceFile.readAll();
   SpiceFile.close();
-  SimProcess.writeToStdin(SpiceContent);
+  QString command(SpiceContent); //to convert byte array to string
+  SimProcess.setStandardInputFile(command);  //? FIXME works?
+  qDebug() << command;
   connect(&SimProcess, SIGNAL(wroteToStdin()), SLOT(slotCloseStdin()));
 }
 
 // ------------------------------------------------------------------------
 void SimMessage::slotCloseStdin()
 {
-  SimProcess.closeStdin();
+  //SimProcess.closeStdin(); //? channel not available in Qt4?
   disconnect(&SimProcess, SIGNAL(wroteToStdin()), 0, 0);
 }
 
@@ -240,7 +268,7 @@ void SimMessage::slotReadSpiceNetlist()
 {
   int i;
   QString s;
-  ProgressText += QString(SimProcess.readStdout());
+  ProgressText += QString(SimProcess.readAllStandardOutput());
 
   while((i = ProgressText.find('\n')) >= 0) {
 
@@ -260,7 +288,7 @@ void SimMessage::slotReadSpiceNetlist()
 }
 
 // ------------------------------------------------------------------------
-void SimMessage::slotFinishSpiceNetlist()
+void SimMessage::slotFinishSpiceNetlist(int status )
 {
   if(makeSubcircuit)
     Stream << ".Def:End\n\n";
@@ -292,7 +320,8 @@ void SimMessage::startSimulator()
   // faster than the user (I have no other idea).
 
   QString SimTime;
-  QStringList CommandLine;
+  QString Program;
+  QStringList Arguments;
   QString SimPath = QDir::convertSeparators (QucsHomeDir.absPath());
 #ifdef __MINGW32__
   QString QucsDigiLib = "qucsdigilib.bat";
@@ -320,14 +349,23 @@ void SimMessage::startSimulator()
     if (Doc->simulation) {
       SimTime = Doc->SimTime;
       QString libs = Doc->Libraries.lower();
+#ifdef __MINGW32__
       if(libs.isEmpty()) {
 	libs = "-Wl";
       } else {
 	libs.replace(" ",",-l");
 	libs = "-Wl,-l" + libs;
       }
-      CommandLine << pathName(QucsSettings.BinDir + QucsDigi)
-		  << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
+#else
+      if(libs.isEmpty()) {
+	libs = "-c";
+      } else {
+	libs.replace(" ",",-l");
+	libs = "-c,-l" + libs;
+      }
+#endif
+      Program = pathName(QucsSettings.BinDir + QucsDigi);
+	  Arguments  << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
 		  << pathName(QucsSettings.BinDir) << libs;
     }
     // Module.
@@ -355,15 +393,15 @@ void SimMessage::startSimulator()
       vhdlDir.setPath(vhdlDir.path()+"/"+lib);
       QFile destFile;
       destFile.setName(vhdlDir.filePath(entity+".vhdl"));
-      if(!destFile.open(IO_WriteOnly)) {
+      if(!destFile.open(QIODevice::WriteOnly)) {
 	ErrText->insert(tr("ERROR: Cannot create \"%1\"!")
 			.arg(destFile.name()));
 	return;
       }
       destFile.writeBlock(text.ascii(), text.length());
       destFile.close();
-      CommandLine << pathName(QucsSettings.BinDir + QucsDigiLib)
-		  << "netlist.txt" << pathName(SimPath) << entity << lib;
+      Program = pathName(QucsSettings.BinDir + QucsDigiLib);
+	  Arguments << "netlist.txt" << pathName(SimPath) << entity << lib;
     }
   }
   // Simulate schematic window.
@@ -383,7 +421,7 @@ void SimMessage::startSimulator()
 
     isVerilog = ((Schematic*)DocWidget)->isVerilog;
     SimTime = ((Schematic*)DocWidget)->createNetlist(Stream, SimPorts);
-    if(SimTime.at(0) == '') {
+    if(SimTime.length()>0&&SimTime.at(0) == '\xA7') {
       NetlistFile.close();
       ErrText->insert(SimTime.mid(1));
       FinishSimulation(-1);
@@ -403,44 +441,78 @@ void SimMessage::startSimulator()
 
     if(SimPorts < 0) {
       if((SimOpt = findOptimization((Schematic*)DocWidget))) {
-	((Optimize_Sim*)SimOpt)->createASCOnetlist();
-	CommandLine << QucsSettings.AscoDir + "asco" << "-qucs" <<
-	  QucsHomeDir.filePath("asco_netlist.txt") << "-o" << "asco_out";
+	    ((Optimize_Sim*)SimOpt)->createASCOnetlist();
+	    Program = QucsSettings.AscoDir + "asco"+ executablePostfix; 
+        Arguments << "-qucs" << QucsHomeDir.filePath("asco_netlist.txt") 
+                  << "-o" << "asco_out";
       }
       else {
-	CommandLine << QucsSettings.BinDir + "qucsator" << "-b" << "-g"
-           << "-i" << QucsHomeDir.filePath("netlist.txt") << "-o" << DataSet;
+	    Program = QucsSettings.BinDir + "qucsator" + executablePostfix;
+
+        Arguments << "-b" << "-g" << "-i" 
+                  << QucsHomeDir.filePath("netlist.txt") 
+                  << "-o" << DataSet;
       }
     } else {
       if (isVerilog) {
-	CommandLine << pathName(QucsSettings.BinDir + QucsVeri)
-		    << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
-		    << pathName(QucsSettings.BinDir) << "-c";
+          Program = pathName(QucsSettings.BinDir + QucsVeri);
+		  Arguments << "netlist.txt" << DataSet 
+                    << SimTime << pathName(SimPath)
+                    << pathName(QucsSettings.BinDir) << "-c";
       } else {
-	CommandLine << pathName(QucsSettings.BinDir + QucsDigi)
-		    << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
-		    << pathName(QucsSettings.BinDir) << "-Wl" << "-c";
+#ifdef __MINGW32__
+	Program = pathName(QucsSettings.BinDir + QucsDigi);
+	Arguments << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
+		      << pathName(QucsSettings.BinDir) << "-Wl" << "-c";
+#else
+	Program = pathName(QucsSettings.BinDir + QucsDigi);
+	Arguments << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
+		      << pathName(QucsSettings.BinDir) << "-Wall" << "-c";
+
+#endif
       }
     }
   }
 
-  SimProcess.setArguments(CommandLine);
-
   disconnect(&SimProcess, 0, 0, 0);
-  connect(&SimProcess, SIGNAL(readyReadStderr()), SLOT(slotDisplayErr()));
-  connect(&SimProcess, SIGNAL(readyReadStdout()), SLOT(slotDisplayMsg()));
-  connect(&SimProcess, SIGNAL(processExited()), SLOT(slotSimEnded()));
+  connect(&SimProcess, SIGNAL(readyReadStandardError()), SLOT(slotDisplayErr()));
+  connect(&SimProcess, SIGNAL(readyReadStandardOutput()), SLOT(slotDisplayMsg()));
+  connect(&SimProcess, SIGNAL(finished(int)), SLOT(slotSimEnded(int)));
 
 #ifdef SPEEDUP_PROGRESSBAR
   waitForUpdate = false;
 #endif
   wasLF = false;
+  
   ProgressText = "";
-  if(!SimProcess.start()) {
+  
+#ifdef __MINGW32__  
+  QString sep(";"); // path separator
+#else  
+  QString sep(":");
+#endif
+  
+  // append process PATH 
+  QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+  env.insert("PATH", env.value("PATH") + sep + QucsSettings.BinDir );
+  SimProcess.setProcessEnvironment(env); 
+  QFile file(Program);
+  if ( !file.exists() ){
+    ErrText->insert(tr("ERROR: Program not found: %1").arg(Program));
+    FinishSimulation(-1);
+    return;
+  }
+  else
+    file.close();
+  
+  SimProcess.start(Program, Arguments); // launch the program
+  
+  if(!SimProcess.Running) {
     ErrText->insert(tr("ERROR: Cannot start simulator!"));
     FinishSimulation(-1);
     return;
   }
+	
 }
 
 // ------------------------------------------------------------------------
@@ -459,7 +531,7 @@ Component * SimMessage::findOptimization(Schematic *Doc) {
 void SimMessage::slotDisplayMsg()
 {
   int i;
-  ProgressText += QString(SimProcess.readStdout());
+  ProgressText += QString(SimProcess.readAllStandardOutput());
   if(wasLF) {
     i = ProgressText.findRev('\r');
 #ifdef __MINGW32__
@@ -476,14 +548,15 @@ void SimMessage::slotDisplayMsg()
         waitForUpdate = true;
       }
 #else
-      SimProgress->setProgress(
+      SimProgress->setMaximum(100);
+      SimProgress->setValue(
          10*int(ProgressText.at(i-2).latin1()-'0') +
-            int(ProgressText.at(i-1).latin1()-'0'), 100);
+            int(ProgressText.at(i-1).latin1()-'0'));
 #endif
       ProgressText.remove(0, i+1);
     }
 
-    if(ProgressText.at(0).latin1() <= '\t')
+    if(ProgressText.size()>0&&ProgressText.at(0).latin1() <= '\t')
       return;
   }
   else {
@@ -514,18 +587,16 @@ void SimMessage::slotUpdateProgressBar()
 // Is called when the process sends an output to stderr.
 void SimMessage::slotDisplayErr()
 {
-  int par = ErrText->paragraphs();
-  int idx = ErrText->paragraphLength(par-1);
-  ErrText->setCursorPosition(par-1,idx);
-  ErrText->insert(QString(SimProcess.readStderr()));
+  QTextCursor cursor = ErrText->textCursor();
+  cursor.movePosition(QTextCursor::End);  
+  ErrText->insert(QString(SimProcess.readAllStandardError()));
 }
 
 // ------------------------------------------------------------------------
 // Is called when the simulation process terminates.
-void SimMessage::slotSimEnded()
-{
-  int stat = (!SimProcess.normalExit()) ? -1 : SimProcess.exitStatus();
-  FinishSimulation(stat);
+void SimMessage::slotSimEnded(int status)
+{ 
+  FinishSimulation(status); //0 - normal  | 1 - crash
 }
 
 // ------------------------------------------------------------------------
@@ -535,7 +606,7 @@ void SimMessage::FinishSimulation(int Status)
 {
   Abort->setText(tr("Close window"));
   Display->setDisabled(false);
-  SimProgress->setProgress(100, 100);   // progress bar to 100%
+  SimProgress->setValue(100);  // progress bar to 100%
 
   QDate d = QDate::currentDate();   // get date of today
   QTime t = QTime::currentTime();   // get time
@@ -554,15 +625,15 @@ void SimMessage::FinishSimulation(int Status)
   }
 
   QFile file(QucsHomeDir.filePath("log.txt"));  // save simulator messages
-  if(file.open(IO_WriteOnly)) {
+  if(file.open(QIODevice::WriteOnly)) {
     int z;
     QTextStream stream(&file);
     stream << tr("Output:\n-------") << "\n\n";
-    for(z=0; z<=ProgText->paragraphs(); z++)
-      stream << ProgText->text(z) << "\n";
+    for(z=0; z<=ProgText->document()->blockCount(); z++)
+      stream << ProgText->document()->findBlock(z).text() << "\n";
     stream << "\n\n\n" << tr("Errors:\n-------") << "\n\n";
-    for(z=0; z<ErrText->paragraphs(); z++)
-      stream << ErrText->text(z) << "\n";
+    for(z=0; z<ErrText->document()->blockCount(); z++)
+      stream << ErrText->document()->findBlock(z).text() << "\n";
     file.close();
   }
 
@@ -570,8 +641,8 @@ void SimMessage::FinishSimulation(int Status)
     if(SimOpt) { // save optimization data
       QFile ifile(QucsHomeDir.filePath("asco_out.dat"));
       QFile ofile(DataSet);
-      if(ifile.open(IO_ReadOnly)) {
-	if(ofile.open(IO_WriteOnly)) {
+      if(ifile.open(QIODevice::ReadOnly)) {
+	if(ofile.open(QIODevice::WriteOnly)) {
 	  QByteArray data = ifile.readAll();
 	  ofile.writeBlock(data);
 	  ofile.close();
