@@ -18,7 +18,7 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-
+#include <QtGui>
 #include <stdlib.h>
 #include <ctype.h>
 #include <math.h>
@@ -30,7 +30,7 @@
 #include <qtextcodec.h>
 #include <qtranslator.h>
 #include <qfile.h>
-#include <qtextstream.h>
+#include <q3textstream.h>
 #include <qmessagebox.h>
 #include <qregexp.h>
 
@@ -50,9 +50,9 @@ QString lastDir;    // to remember last directory for several dialogs
 bool loadSettings()
 {
   QFile file(QucsHomeDir.filePath("qucsrc"));
-  if(!file.open(IO_ReadOnly)) return false; // settings file doesn't exist
+  if(!file.open(QIODevice::ReadOnly)) return false; // settings file doesn't exist
 
-  QTextStream stream(&file);
+  Q3TextStream stream(&file);
   QString Line, Setting;
 
   bool ok;
@@ -107,13 +107,13 @@ bool loadSettings()
 bool saveApplSettings(QucsApp *qucs)
 {
   QFile file(QucsHomeDir.filePath("qucsrc"));
-  if(!file.open(IO_WriteOnly)) {    // settings file cannot be created
+  if(!file.open(QIODevice::WriteOnly)) {    // settings file cannot be created
     QMessageBox::warning(0, QObject::tr("Warning"),
 			QObject::tr("Cannot save settings !"));
     return false;
   }
 
-  QTextStream stream(&file);
+  Q3TextStream stream(&file);
 
   stream << "Settings file, Qucs " PACKAGE_VERSION "\n"
     << "Position=" << qucs->x() << "," << qucs->y() << "\n"
@@ -144,6 +144,14 @@ bool saveApplSettings(QucsApp *qucs)
 }
 
 // #########################################################################
+// #########################################################################
+// ##########                                                     ##########
+// ##########            MOVE SOMEWHERE ELSE START                ##########
+// ##########                                                     ##########
+// #########################################################################
+
+
+
 QString complexRect(double real, double imag, int Precision)
 {
   QString Text;
@@ -151,7 +159,7 @@ QString complexRect(double real, double imag, int Precision)
   else {
     Text = QString::number(imag,'g',Precision);
     if(Text.at(0) == '-') {
-      Text.at(0) = 'j';
+      Text.replace(0,1,'j');
       Text = '-'+Text;
     }
     else  Text = "+j"+Text;
@@ -166,7 +174,7 @@ QString complexDeg(double real, double imag, int Precision)
   if(fabs(imag) < 1e-250) Text = QString::number(real,'g',Precision);
   else {
     Text  = QString::number(sqrt(real*real+imag*imag),'g',Precision) + " / ";
-    Text += QString::number(180.0/M_PI*atan2(imag,real),'g',Precision) + '';
+    Text += QString::number(180.0/M_PI*atan2(imag,real),'g',Precision) + QString::fromUtf8("°");
   }
   return Text;
 }
@@ -278,20 +286,26 @@ void str2num(const QString& s_, double& Number, QString& Unit, double& Factor)
 
   Number = str.left(i).toDouble();
   Unit   = str.mid(i).stripWhiteSpace();
-
-  switch(Unit.at(0).latin1()) {
-    case 'T': Factor = 1e12;  break;
-    case 'G': Factor = 1e9;   break;
-    case 'M': Factor = 1e6;   break;
-    case 'k': Factor = 1e3;   break;
-    case 'c': Factor = 1e-2;  break;
-    case 'm': Factor = 1e-3;  break;
-    case 'u': Factor = 1e-6;  break;
-    case 'n': Factor = 1e-9;  break;
-    case 'p': Factor = 1e-12; break;
-    case 'f': Factor = 1e-15; break;
-//    case 'd':
-    default:  Factor = 1.0;
+  if(Unit.length()>0)
+  {
+    switch(Unit.at(0).latin1()) {
+      case 'T': Factor = 1e12;  break;
+      case 'G': Factor = 1e9;   break;
+      case 'M': Factor = 1e6;   break;
+      case 'k': Factor = 1e3;   break;
+      case 'c': Factor = 1e-2;  break;
+      case 'm': Factor = 1e-3;  break;
+      case 'u': Factor = 1e-6;  break;
+      case 'n': Factor = 1e-9;  break;
+      case 'p': Factor = 1e-12; break;
+      case 'f': Factor = 1e-15; break;
+  //    case 'd':
+      default:  Factor = 1.0;
+    }
+  }
+  else
+  {
+    Factor = 1.0;
   }
 
   return;
@@ -355,7 +369,7 @@ void convert2ASCII(QString& Text)
   int i = 0;
   QChar ch;
   char Str[8];
-  while((ch=Text.at(i++)) != QChar(0)) {  // convert special characters
+  while(Text.size()<i) {  // convert special characters
     if(ch > QChar(0x7F)) {
       sprintf(Str, "\\x%04X", ch.unicode());
       Text.replace(ch, Str);
@@ -434,7 +448,7 @@ bool VHDL_Time(QString& t, const QString& Name)
       if(strcmp(p, "min") == 0) break;
       if(strcmp(p, "hr") == 0)  break;
     }
-    t = "" + QObject::tr("Error: Wrong time format in \"%1\". Use positive number with units").arg(Name)
+    t = QString::fromUtf8("§")  + QObject::tr("Error: Wrong time format in \"%1\". Use positive number with units").arg(Name)
             + " fs, ps, ns, us, ms, sec, min, hr.\n";
     return false;
   }
@@ -497,7 +511,7 @@ bool Verilog_Time(QString& t, const QString& Name)
       if(strcmp(p, "min") == 0) { factor = 1e12*60; break; }
       if(strcmp(p, "hr") == 0)  { factor = 1e12*60*60; break; }
     }
-    t = "" + QObject::tr("Error: Wrong time format in \"%1\". Use positive number with units").arg(Name)
+    t = QString::fromUtf8("§")  + QObject::tr("Error: Wrong time format in \"%1\". Use positive number with units").arg(Name)
             + " fs, ps, ns, us, ms, sec, min, hr.\n";
     return false;
   }
@@ -513,14 +527,19 @@ bool checkVersion(QString& Line)
   QStringList ll = QStringList::split('.',Line);
   if (ll.count() != 3 || sl.count() != 3)
     return false;
-  int sv = (*sl.at(1)).toInt() * 10000 + (*sl.at(2)).toInt() * 100 +
-    (*sl.at(3)).toInt();
-  int lv = (*ll.at(1)).toInt() * 10000 + (*ll.at(2)).toInt() * 100 +
-    (*ll.at(3)).toInt();
+  int sv = (int)sl.at(1).toLongLong()*10000+sl.at(2).toLongLong()*100;
+  int lv = (int)ll.at(1).toLongLong()*10000+ll.at(2).toLongLong()*100;
   if(lv > sv) // wrong version number ? (only backward compatible)
     return false;
   return true;
 }
+// #########################################################################
+// ##########                                                     ##########
+// ##########            MOVE SOMEWHERE ELSE END                  ##########
+// ##########                                                     ##########
+// #########################################################################
+
+
 
 
 // #########################################################################
@@ -562,15 +581,20 @@ int main(int argc, char *argv[])
       QDir::convertSeparators (QucsDirStr + "/share/qucs/library/");
     QucsSettings.OctaveDir =
       QDir::convertSeparators (QucsDirStr + "/share/qucs/octave/");
+    QucsSettings.ExamplesDir = 
+      QDir::convertSeparators (QucsDirStr + "/share/qucs/docs/examples/");
+    QucsSettings.DocDir = 
+      QDir::convertSeparators (QucsDirStr + "/share/qucs/docs/");
   } else {
     QucsSettings.BinDir = BINARYDIR;
     QucsSettings.BitmapDir = BITMAPDIR;
     QucsSettings.LangDir = LANGUAGEDIR;
     QucsSettings.LibDir = LIBRARYDIR;
     QucsSettings.OctaveDir = OCTAVEDIR;
+    QucsSettings.ExamplesDir = QDir(DOCDIR).canonicalPath()+"/examples/";
+    QucsSettings.DocDir = DOCDIR;
   }
   QucsSettings.Editor = QucsSettings.BinDir + "qucsedit";
-
   QucsWorkDir.setPath(QDir::homeDirPath()+QDir::convertSeparators ("/.qucs"));
   QucsHomeDir.setPath(QDir::homeDirPath()+QDir::convertSeparators ("/.qucs"));
   loadSettings();
@@ -604,8 +628,16 @@ int main(int argc, char *argv[])
     QString AscoDirStr = AscoDir.canonicalPath ();
     QucsSettings.AscoDir =
       QDir::convertSeparators (AscoDirStr + "/bin/");
-  } else {
-    QucsSettings.AscoDir = "";
+  } 
+  else {
+    QFile file("/usr/local/bin/asco");
+    if ( file.exists() ){
+      QucsSettings.AscoDir =
+          QDir::convertSeparators ("/usr/local/bin/");
+      file.close();
+    }
+    else
+      QucsSettings.AscoDir = "";
   }
 
   a.setFont(QucsSettings.font);
