@@ -20,7 +20,7 @@
 
 #include <qfont.h>
 #include <qcolor.h>
-#include <qptrlist.h>
+#include <q3ptrlist.h>
 #include <qstringlist.h>
 
 #include "wire.h"
@@ -55,6 +55,8 @@ struct tQucsSettings {
   QString LibDir;
   QString AscoDir;
   QString OctaveDir;
+  QString ExamplesDir;
+  QString DocDir;
 
   unsigned int NodeWiring;
 
