@@ -14,14 +14,16 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include "arrow.h"
 #include "arrowdialog.h"
+#include "schematic.h"
 
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qcombobox.h>
-
+//Added by qt3to4:
+#include <Q3PointArray>
 #include <math.h>
 
 
@@ -48,36 +50,36 @@ Arrow::~Arrow()
 // --------------------------------------------------------------------------
 void Arrow::paint(ViewPainter *p)
 {
-  QPointArray Points;
+  Q3PointArray Points;
   int x1_, y1_, x2_, y2_, x3_, y3_;
   if(isSelected) {
-    p->Painter->setPen(QPen(QPen::darkGray,Pen.width()+5));
+    p->Painter->setPen(QPen(Qt::darkGray,Pen.width()+5));
     p->drawLine(cx, cy, cx+x2, cy+y2);
     p->drawLine(cx+x2, cy+y2, cx+xp1, cy+yp1);
     p->drawLine(cx+x2, cy+y2, cx+xp2, cy+yp2);
     if(Style == 0) {   // arrow head with two lines ?
-      p->Painter->setPen(QPen(QPen::white, Pen.width(), Pen.style()));
+      p->Painter->setPen(QPen(Qt::white, Pen.width(), Pen.style()));
       p->drawLine(cx, cy, cx+x2, cy+y2);
-      p->Painter->setPen(QPen(QPen::white, Pen.width(), Qt::SolidLine));
+      p->Painter->setPen(QPen(Qt::white, Pen.width(), Qt::SolidLine));
       p->drawLine(cx+x2, cy+y2, cx+xp1, cy+yp1);
       p->drawLine(cx+x2, cy+y2, cx+xp2, cy+yp2);
     }
     else {   // filled arrow head
       p->drawLine(cx+xp1, cy+yp1, cx+xp2, cy+yp2);
-      p->Painter->setPen(QPen(QPen::white, Pen.width(), Pen.style()));
+      p->Painter->setPen(QPen(Qt::white, Pen.width(), Pen.style()));
       p->drawLine(cx, cy, cx+x2, cy+y2);
 
-      p->Painter->setPen(QPen(QPen::white, Pen.width(), Qt::SolidLine));
-      p->Painter->setBrush(QPen::white);
+      p->Painter->setPen(QPen(Qt::white, Pen.width(), Qt::SolidLine));
+      p->Painter->setBrush(Qt::white);
       p->map(cx+xp1, cy+yp1, x1_, y1_);
       p->map(cx+x2, cy+y2, x2_, y2_);
       p->map(cx+xp2, cy+yp2, x3_, y3_);
       Points.setPoints(3, x1_, y1_, x2_, y2_, x3_, y3_);
       p->Painter->drawConvexPolygon(Points);
-      p->Painter->setBrush(QBrush::NoBrush); // no filling for next paintings
+      p->Painter->setBrush(Qt::NoBrush); // no filling for next paintings
     }
 
-    p->Painter->setPen(QPen(QPen::darkRed,2));
+    p->Painter->setPen(QPen(Qt::darkRed,2));
     p->drawResizeRect(cx, cy);  // markers for changing the size
     p->drawResizeRect(cx+x2, cy+y2);
     return;
@@ -96,16 +98,16 @@ void Arrow::paint(ViewPainter *p)
     p->map(cx+xp2, cy+yp2, x3_, y3_);
     Points.setPoints(3, x1_, y1_, x2_, y2_, x3_, y3_);
     p->Painter->drawConvexPolygon(Points);
-    p->Painter->setBrush(QBrush::NoBrush); // no filling for next paintings
+    p->Painter->setBrush(Qt::NoBrush); // no filling for next paintings
   }
 }
 
 // --------------------------------------------------------------------------
-void Arrow::paintScheme(QPainter *p)
+void Arrow::paintScheme(Schematic *p)
 {
-  p->drawLine(cx, cy, cx+x2, cy+y2);
-  p->drawLine(cx+x2, cy+y2, cx+xp1, cy+yp1);
-  p->drawLine(cx+x2, cy+y2, cx+xp2, cy+yp2);
+  p->PostPaintEvent(_Line, cx, cy, cx+x2, cy+y2,0,0,false);
+  p->PostPaintEvent(_Line, cx+x2, cy+y2, cx+xp1, cy+yp1,0,0,false);
+  p->PostPaintEvent(_Line, cx+x2, cy+y2, cx+xp2, cy+yp2,0,0,false);
 }
 
 // --------------------------------------------------------------------------
@@ -241,7 +243,7 @@ bool Arrow::resizeTouched(float fX, float fY, float len)
 
 // --------------------------------------------------------------------------
 // Mouse move action during resize.
-void Arrow::MouseResizeMoving(int x, int y, QPainter *p)
+void Arrow::MouseResizeMoving(int x, int y, Schematic *p)
 {
   paintScheme(p);  // erase old painting
   if(State == 1) { x2 += cx-x; y2 += cy-y; cx = x; cy = y; } // moving shaft
@@ -269,8 +271,8 @@ void Arrow::calcArrowHead()
 // fx/fy are the precise coordinates, gx/gy are the coordinates set on grid.
 // x/y are coordinates without scaling.
 void Arrow::MouseMoving(
-	QPainter *paintScale, int, int, int gx, int gy,
-	QPainter *p, int x, int y, bool drawn)
+	Schematic *paintScale, int, int, int gx, int gy,
+	Schematic *p, int x, int y, bool drawn)
 {
   if(State > 0) {
     if(State > 1) {
@@ -286,17 +288,17 @@ void Arrow::MouseMoving(
   else { cx = gx; cy = gy; }
 
 
-  p->setPen(Qt::SolidLine);
+#warning  p->setPen(Qt::SolidLine);
   if(drawn) {
-    p->drawLine(x1+25, y1, x1+13, y1+12);  // erase old cursor symbol
-    p->drawLine(x1+18, y1+2, x1+25, y1);
-    p->drawLine(x1+23, y1+7, x1+25, y1);
+    p->PostPaintEvent(_Line, x1+25, y1, x1+13, y1+12,0,0,true);  // erase old cursor symbol
+    p->PostPaintEvent(_Line, x1+18, y1+2, x1+25, y1,0,0,true);
+    p->PostPaintEvent(_Line, x1+23, y1+7, x1+25, y1,0,0,true);
   }
   x1 = x;
   y1 = y;
-  p->drawLine(x1+25, y1, x1+13, y1+12);  // paint new cursor symbol
-  p->drawLine(x1+18, y1+2, x1+25, y1);
-  p->drawLine(x1+23, y1+7, x1+25, y1);
+  p->PostPaintEvent(_Line, x1+25, y1, x1+13, y1+12,0,0,true);  // paint new cursor symbol
+  p->PostPaintEvent(_Line, x1+18, y1+2, x1+25, y1,0,0,true);
+  p->PostPaintEvent(_Line, x1+23, y1+7, x1+25, y1,0,0,true);
 }
 
 // --------------------------------------------------------------------------
