@@ -28,7 +28,7 @@ public:
   EllipseArc();
  ~EllipseArc();
 
-  void paintScheme(QPainter*);
+  void paintScheme(Schematic*);
   void getCenter(int&, int&);
   void setCenter(int, int, bool relative=false);
 
@@ -38,11 +38,11 @@ public:
   QString save();
   QString saveCpp();
   void paint(ViewPainter*);
-  void MouseMoving(QPainter*, int, int, int, int, QPainter*, int, int, bool);
+  void MouseMoving(Schematic*, int, int, int, int, Schematic*, int, int, bool);
   bool MousePressing();
   bool getSelected(float, float, float);
   bool resizeTouched(float, float, float);
-  void MouseResizeMoving(int, int, QPainter*);
+  void MouseResizeMoving(int, int, Schematic*);
 
   void rotate();
   void mirrorX();
