@@ -27,7 +27,7 @@ public:
               QPen Pen_=QPen(QColor()));
  ~GraphicLine();
 
-  void paintScheme(QPainter*);
+  void paintScheme(Schematic*);
   void getCenter(int&, int&);
   void setCenter(int, int, bool relative=false);
 
@@ -37,12 +37,12 @@ public:
   QString save();
   QString saveCpp();
   void paint(ViewPainter*);
-  void MouseMoving(QPainter*, int, int, int, int, QPainter*, int, int, bool);
+  void MouseMoving(Schematic*, int, int, int, int, Schematic*, int, int, bool);
   bool MousePressing();
   bool getSelected(float, float, float);
   void Bounding(int&, int&, int&, int&);
   bool resizeTouched(float, float, float);
-  void MouseResizeMoving(int, int, QPainter*);
+  void MouseResizeMoving(int, int, Schematic*);
 
   void rotate();
   void mirrorX();
