@@ -14,17 +14,18 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include "main.h"
 #include "mnemo.h"
 #include "viewpainter.h"
 #include "graphictext.h"
 #include "graphictextdialog.h"
-
+#include "schematic.h"
+#include "qucs.h"
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 #include <qpushbutton.h>
 
 #include <math.h>
@@ -49,8 +50,8 @@ GraphicText::~GraphicText()
 // -----------------------------------------------------------------------
 void GraphicText::paint(ViewPainter *p)
 {
-  QWMatrix wm = p->Painter->worldMatrix();
-  QWMatrix Mat(1.0, 0.0, 0.0, 1.0, p->DX + float(cx) * p->Scale,
+  QMatrix wm = p->Painter->worldMatrix();
+  QMatrix Mat(1.0, 0.0, 0.0, 1.0, p->DX + float(cx) * p->Scale,
 				   p->DY + float(cy) * p->Scale);
   p->Painter->setWorldMatrix(Mat);
   p->Painter->rotate(-Angle);   // automatically enables transformation
@@ -70,7 +71,7 @@ void GraphicText::paint(ViewPainter *p)
   w = p->drawTextMapped(Text, 0, 0, &h);
 
   if(isSelected) {
-    p->Painter->setPen(QPen(QPen::darkGray,3));
+    p->Painter->setPen(QPen(Qt::darkGray,3));
     p->Painter->drawRect(-3, -2, w+6, h+5);
   }
 
@@ -83,17 +84,17 @@ void GraphicText::paint(ViewPainter *p)
 }
 
 // -----------------------------------------------------------------------
-void GraphicText::paintScheme(QPainter *p)
+void GraphicText::paintScheme(Schematic *p)
 {
-  QWMatrix wm = p->worldMatrix();
-  QWMatrix Mat (wm.m11(), 0.0, 0.0, wm.m22(),
-		wm.dx() + double(cx) * wm.m11(),
-		wm.dy() + double(cy) * wm.m22());
-  p->setWorldMatrix(Mat);
-  p->rotate(-Angle);
-  p->drawRect(0, 0, x2, y2);
+  #warning QMatrix wm = p->worldMatrix();
+  #warning QMatrix Mat (wm.m11(), 0.0, 0.0, wm.m22(),
+#warning 		wm.dx() + double(cx) * wm.m11(),
+#warning 		wm.dy() + double(cy) * wm.m22());
+  #warning p->setWorldMatrix(Mat);
+  #warning p->rotate(-Angle);
+  p->PostPaintEvent(_Rect, 0, 0, x2, y2);
 
-  p->setWorldMatrix(wm);
+  #warning p->setWorldMatrix(wm);
 }
 
 // ------------------------------------------------------------------------
@@ -158,7 +159,7 @@ bool GraphicText::load(const QString& s)
   if(Text.isEmpty()) return false;
 
   convert2Unicode(Text);
-  QFontMetrics  metrics(Font);
+  QFontMetrics  metrics(((Schematic*)QucsMain->DocumentTab->currentPage())->font());   // get size of text
   QSize r = metrics.size(0, Text);    // get size of text
   x2 = r.width();
   y2 = r.height();
@@ -198,20 +199,20 @@ QString GraphicText::saveCpp()
 // fx/fy are the precise coordinates, gx/gy are the coordinates set on grid.
 // x/y are coordinates without scaling.
 void GraphicText::MouseMoving(
-	QPainter*, int, int, int gx, int gy,
-	QPainter *p, int x, int y, bool drawn)
+	Schematic*, int, int, int gx, int gy,
+	Schematic *p, int x, int y, bool drawn)
 {
-  p->setPen(Qt::SolidLine);
+  #warning p->setPen(Qt::SolidLine);
   if(drawn) {
-    p->drawLine(x1+15, y1+15, x1+20, y1);  // erase old cursor symbol
-    p->drawLine(x1+26, y1+15, x1+21, y1);
-    p->drawLine(x1+17, y1+8,  x1+23, y1+8);
+    p->PostPaintEvent(_Line, x1+15, y1+15, x1+20, y1,0,0,true);  // erase old cursor symbol
+    p->PostPaintEvent(_Line, x1+26, y1+15, x1+21, y1,0,0,true);
+    p->PostPaintEvent(_Line, x1+17, y1+8,  x1+23, y1+8,0,0,true);
   }
   x1 = x;
   y1 = y;
-  p->drawLine(x1+15, y1+15, x1+20, y1);  // paint new cursor symbol
-  p->drawLine(x1+26, y1+15, x1+21, y1);
-  p->drawLine(x1+17, y1+8,  x1+23, y1+8);
+  p->PostPaintEvent(_Line, x1+15, y1+15, x1+20, y1,0,0,true);  // paint new cursor symbol
+  p->PostPaintEvent(_Line, x1+26, y1+15, x1+21, y1,0,0,true);
+  p->PostPaintEvent(_Line, x1+17, y1+8,  x1+23, y1+8,0,0,true);
 
   cx = gx;
   cy = gy;
@@ -335,8 +336,8 @@ bool GraphicText::Dialog()
       Text = _Text;
       changed = true;
     }
-
-  QFontMetrics  m(f);
+  QFontMetrics  m(((Schematic*)QucsMain->DocumentTab->currentPage())->font());   // get size of text
+#warning is this the right way? it was this: QFontMetrics  m(f);
   QSize s = m.size(0, Text);    // get size of text
   x2 = s.width();
   y2 = s.height();
