@@ -18,7 +18,8 @@
 #ifndef GRAPHICTEXTDIALOG_H
 #define GRAPHICTEXTDIALOG_H
 
-#include <qdialog.h>
+#include <QDialog>
+#include <QVBoxLayout>
 
 class QLineEdit;
 class QTextEdit;
@@ -42,6 +43,7 @@ public:
   QPushButton *ColorButt;
   QTextEdit   *text;
 
+private:
   QVBoxLayout *vert;
   QIntValidator *val50, *val360;
 };
