@@ -18,14 +18,18 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-
+#include <QtGui>
 #include <qmessagebox.h>
 #include <qdir.h>
 #include <qstringlist.h>
 #include <qregexp.h>
-#include <qprocess.h>
-#include <qtextedit.h>
-#include <qptrlist.h>
+#include <q3process.h>
+#include <q3textedit.h>
+#include <QTextEdit>
+#include <q3ptrlist.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3ValueList>
 
 #include "main.h"
 #include "node.h"
@@ -100,7 +104,7 @@ QString Schematic::createClipboardFile()
 
 // -------------------------------------------------------------
 // Only read fields without loading them.
-bool Schematic::loadIntoNothing(QTextStream *stream)
+bool Schematic::loadIntoNothing(Q3TextStream *stream)
 {
   QString Line, cstr;
   while(!stream->atEnd()) {
@@ -115,7 +119,7 @@ bool Schematic::loadIntoNothing(QTextStream *stream)
 
 // -------------------------------------------------------------
 // Paste from clipboard.
-bool Schematic::pasteFromClipboard(QTextStream *stream, QPtrList<Element> *pe)
+bool Schematic::pasteFromClipboard(Q3TextStream *stream, Q3PtrList<Element> *pe)
 {
   QString Line;
 
@@ -145,7 +149,7 @@ bool Schematic::pasteFromClipboard(QTextStream *stream, QPtrList<Element> *pe)
         if(!loadIntoNothing(stream)) return false; }
       else
       if(Line == "<Paintings>") {
-        if(!loadPaintings(stream, (QPtrList<Painting>*)pe)) return false; }
+        if(!loadPaintings(stream, (Q3PtrList<Painting>*)pe)) return false; }
       else {
         QMessageBox::critical(0, QObject::tr("Error"),
 		   QObject::tr("Clipboard Format Error:\nUnknown field!"));
@@ -160,16 +164,16 @@ bool Schematic::pasteFromClipboard(QTextStream *stream, QPtrList<Element> *pe)
   while(!stream->atEnd()) {
     Line = stream->readLine();
     if(Line == "<Components>") {
-      if(!loadComponents(stream, (QPtrList<Component>*)pe)) return false; }
+      if(!loadComponents(stream, (Q3PtrList<Component>*)pe)) return false; }
     else
     if(Line == "<Wires>") {
       if(!loadWires(stream, pe)) return false; }
     else
     if(Line == "<Diagrams>") {
-      if(!loadDiagrams(stream, (QPtrList<Diagram>*)pe)) return false; }
+      if(!loadDiagrams(stream, (Q3PtrList<Diagram>*)pe)) return false; }
     else
     if(Line == "<Paintings>") {
-      if(!loadPaintings(stream, (QPtrList<Painting>*)pe)) return false; }
+      if(!loadPaintings(stream, (Q3PtrList<Painting>*)pe)) return false; }
     else {
       QMessageBox::critical(0, QObject::tr("Error"),
 		   QObject::tr("Clipboard Format Error:\nUnknown field!"));
@@ -187,13 +191,13 @@ int Schematic::saveSymbolCpp (void)
   QString cppfile = info.dirPath () + QDir::separator() + DataSet;
   QFile file (cppfile);
 
-  if (!file.open (IO_WriteOnly)) {
+  if (!file.open (QIODevice::WriteOnly)) {
     QMessageBox::critical (0, QObject::tr("Error"),
 		   QObject::tr("Cannot save C++ file \"%1\"!").arg(cppfile));
     return -1;
   }
 
-  QTextStream stream (&file);
+  Q3TextStream stream (&file);
 
   // automatically compute boundings of drawing
   int xmin = INT_MAX;
@@ -210,6 +214,12 @@ int Schematic::saveSymbolCpp (void)
     if (pp->Name == ".PortSym ") {
       if (((PortSymbol*)pp)->numberStr.toInt() > maxNum)
 	maxNum = ((PortSymbol*)pp)->numberStr.toInt();
+      x1 = ((PortSymbol*)pp)->cx;
+      y1 = ((PortSymbol*)pp)->cy;
+      if (x1 < xmin) xmin = x1;
+      if (x1 > xmax) xmax = x1;
+      if (y1 < ymin) ymin = y1;
+      if (y1 > ymax) ymax = y1;
       continue;
     }
     pp->Bounding (x1, y1, x2, y2);
@@ -247,13 +257,13 @@ int Schematic::saveSymbolCpp (void)
 int Schematic::saveDocument()
 {
   QFile file(DocName);
-  if(!file.open(IO_WriteOnly)) {
+  if(!file.open(QIODevice::WriteOnly)) {
     QMessageBox::critical(0, QObject::tr("Error"),
 				QObject::tr("Cannot save document!"));
     return -1;
   }
 
-  QTextStream stream(&file);
+  Q3TextStream stream(&file);
 
   stream << "<Qucs Schematic " << PACKAGE_VERSION << ">\n";
 
@@ -332,7 +342,7 @@ int Schematic::saveDocument()
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadProperties(QTextStream *stream)
+bool Schematic::loadProperties(Q3TextStream *stream)
 {
   bool ok = true;
   QString Line, cstr, nstr;
@@ -440,7 +450,7 @@ void Schematic::simpleInsertComponent(Component *c)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadComponents(QTextStream *stream, QPtrList<Component> *List)
+bool Schematic::loadComponents(Q3TextStream *stream, Q3PtrList<Component> *List)
 {
   QString Line, cstr;
   Component *c;
@@ -509,7 +519,7 @@ void Schematic::simpleInsertWire(Wire *pw)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadWires(QTextStream *stream, QPtrList<Element> *List)
+bool Schematic::loadWires(Q3TextStream *stream, Q3PtrList<Element> *List)
 {
   Wire *w;
   QString Line;
@@ -546,7 +556,7 @@ bool Schematic::loadWires(QTextStream *stream, QPtrList<Element> *List)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadDiagrams(QTextStream *stream, QPtrList<Diagram> *List)
+bool Schematic::loadDiagrams(Q3TextStream *stream, Q3PtrList<Diagram> *List)
 {
   Diagram *d;
   QString Line, cstr;
@@ -589,7 +599,7 @@ bool Schematic::loadDiagrams(QTextStream *stream, QPtrList<Diagram> *List)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadPaintings(QTextStream *stream, QPtrList<Painting> *List)
+bool Schematic::loadPaintings(Q3TextStream *stream, Q3PtrList<Painting> *List)
 {
   Painting *p=0;
   QString Line, cstr;
@@ -639,14 +649,14 @@ bool Schematic::loadPaintings(QTextStream *stream, QPtrList<Painting> *List)
 bool Schematic::loadDocument()
 {
   QFile file(DocName);
-  if(!file.open(IO_ReadOnly)) {
+  if(!file.open(QIODevice::ReadOnly)) {
     QMessageBox::critical(0, QObject::tr("Error"),
                  QObject::tr("Cannot load document: ")+DocName);
     return false;
   }
 
   QString Line;
-  QTextStream stream(&file);
+  Q3TextStream stream(&file);
 
   // read header **************************
   do {
@@ -724,7 +734,7 @@ QString Schematic::createUndoString(char Op)
 
   // Build element document.
   QString s = "  \n";
-  s.at(0) = Op;
+  s.replace(0,1,Op);
   for(pc = DocComps.first(); pc != 0; pc = DocComps.next())
     s += pc->save()+"\n";
   s += "</>\n";  // short end flag
@@ -755,7 +765,7 @@ QString Schematic::createSymbolUndoString(char Op)
 
   // Build element document.
   QString s = "  \n";
-  s.at(0) = Op;
+  s.replace(0,1,Op);
   s += "</>\n";  // short end flag for components
   s += "</>\n";  // short end flag for wires
   s += "</>\n";  // short end flag for diagrams
@@ -779,7 +789,7 @@ bool Schematic::rebuild(QString *s)
   DocPaints.clear();
 
   QString Line;
-  QTextStream stream(s, IO_ReadOnly);
+  Q3TextStream stream(s, QIODevice::ReadOnly);
   Line = stream.readLine();  // skip identity byte
 
   // read content *************************
@@ -798,7 +808,7 @@ bool Schematic::rebuildSymbol(QString *s)
   SymbolPaints.clear();	// delete whole document
 
   QString Line;
-  QTextStream stream(s, IO_ReadOnly);
+  Q3TextStream stream(s, QIODevice::ReadOnly);
   Line = stream.readLine();  // skip identity byte
 
   // read content *************************
@@ -877,7 +887,7 @@ void Schematic::propagateNode(QStringList& Collect,
 			      int& countInit, Node *pn)
 {
   bool setName=false;
-  QPtrList<Node> Cons;
+  Q3PtrList<Node> Cons;
   Node *p2;
   Wire *pw;
   Element *pe;
@@ -912,7 +922,7 @@ void Schematic::propagateNode(QStringList& Collect,
   Cons.clear();
 }
 
-
+#include <iostream>
 // --------------------------------------------------- 
 // Goes through all schematic components and allows special component
 // handling, e.g. like subcircuit netlisting.
@@ -923,7 +933,7 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
   QString s;
 
   // give the ground nodes the name "gnd", and insert subcircuits etc.
-  QPtrListIterator<Component> it(DocComps);
+  Q3PtrListIterator<Component> it(DocComps);
   Component *pc;
   while((pc = it.current()) != 0) {
     ++it;
@@ -981,14 +991,15 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
       d->creatingLib = creatingLib;
       r = d->createSubNetlist(stream, countInit, Collect, ErrText, NumPorts);
       if (r) {
-	i = 0;
-	// save in/out signal types of subcircuit
-	for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++) {
-	  pp->Type = d->PortTypes[i];
-	  pp->Connection->DType = pp->Type;
-	}
-	sub.PortTypes = d->PortTypes;
-	FileList.replace(f, sub);
+	      i = 0;
+	      // save in/out signal types of subcircuit
+	      for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++) {
+          //if(i>=d->PortTypes.count())break;
+	        pp->Type = d->PortTypes[i];
+	        pp->Connection->DType = pp->Type;
+	      }
+	      sub.PortTypes = d->PortTypes;
+	      FileList.replace(f, sub);
       }
       delete d;
       if(!r) return false;
@@ -1138,7 +1149,6 @@ bool Schematic::createLibNetlist(QTextStream *stream, QTextEdit *ErrText,
   Collect.clear();
   FileList.clear();
   Signals.clear();
-
   // Apply node names and collect subcircuits and file include
   creatingLib = true;
   if(!giveNodeNames(stream, countInit, Collect, ErrText, NumPorts)) {
@@ -1172,7 +1182,7 @@ bool Schematic::createLibNetlist(QTextStream *stream, QTextEdit *ErrText,
 
 // ---------------------------------------------------
 void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
-				      int NumPorts)
+int NumPorts)
 {
   int i, z;
   QString s;
@@ -1181,8 +1191,8 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
   QStringList InPorts;
   QStringList OutPorts;
   QStringList InOutPorts;
-  QStringList::Iterator it_name;
-  QStringList::Iterator it_type;
+  QStringList::iterator it_name;
+  QStringList::iterator it_type;
   Component *pc;
 
   // probably creating a library currently
@@ -1202,7 +1212,7 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
   // "SubcircuitPortNames"
   PortTypes.clear();
   for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-    if(pc->Model.at(0) == '.') {  // no simulations in subcircuits
+    if(pc->Model.at(0) == '.') { // no simulations in subcircuits
       ErrText->insert(
         QObject::tr("WARNING: Ignore simulation component in subcircuit \"%1\".").arg(DocName)+"\n");
       continue;
@@ -1210,48 +1220,54 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
     else if(pc->Model == "Port") {
       i = pc->Props.first()->Value.toInt();
       for(z=SubcircuitPortNames.size(); z<i; z++) { // add empty port names
-	SubcircuitPortNames.append(" ");
-	SubcircuitPortTypes.append(" ");
+        SubcircuitPortNames.append(" ");
+        SubcircuitPortTypes.append(" ");
+      }
+      it_name = SubcircuitPortNames.begin();
+      it_type = SubcircuitPortTypes.begin();
+      for(int n=1;n<i;n++)
+      {
+        it_name++;
+        it_type++;
       }
-      it_name = SubcircuitPortNames.at(i-1);
-      it_type = SubcircuitPortTypes.at(i-1);
       (*it_name) = pc->Ports.getFirst()->Connection->Name;
       DigMap::Iterator it = Signals.find(*it_name);
-      (*it_type) = it.data().Type;
+      if(it!=Signals.end())
+        (*it_type) = it.data().Type;
       // propagate type to port symbol
       pc->Ports.getFirst()->Connection->DType = *it_type;
 
       if(!isAnalog) {
-	if (isVerilog) {
-	  Signals.erase(*it_name); // remove node name
-	  switch(pc->Props.at(1)->Value.at(0).latin1()) {
-          case 'a':
-	    InOutPorts.append(*it_name);
-	    break;
-          case 'o':
-	    OutPorts.append(*it_name);
-	    break;
-          default:
-	    InPorts.append(*it_name);
-	  }
-	}
-	else {
-	  // remove node name of output port
-	  Signals.erase(*it_name);
-	  switch(pc->Props.at(1)->Value.at(0).latin1()) {
-          case 'a':
-	    (*it_name) += " : inout";  // attribute "analog" is "inout"
-	    break;
-          case 'o': // output ports need workaround
-	    Signals.insert(*it_name, DigSignal(*it_name, *it_type));
-	    (*it_name) = "net_out" + (*it_name);
-	    // no "break;" here !!!
-          default:
-	    (*it_name) += " : " + pc->Props.at(1)->Value;
-	  }
-	  (*it_name) += " " + ((*it_type).isEmpty() ?
-			       VHDL_SIGNAL_TYPE : (*it_type));
-	}
+        if (isVerilog) {
+          Signals.erase(*it_name); // remove node name
+          switch(pc->Props.at(1)->Value.at(0).latin1()) {
+            case 'a':
+              InOutPorts.append(*it_name);
+              break;
+            case 'o':
+              OutPorts.append(*it_name);
+              break;
+              default:
+                InPorts.append(*it_name);
+          }
+        }
+        else {
+          // remove node name of output port
+          Signals.erase(*it_name);
+          switch(pc->Props.at(1)->Value.at(0).latin1()) {
+            case 'a':
+              (*it_name) += " : inout"; // attribute "analog" is "inout"
+              break;
+            case 'o': // output ports need workaround
+              Signals.insert(*it_name, DigSignal(*it_name, *it_type));
+              (*it_name) = "net_out" + (*it_name);
+              // no "break;" here !!!
+            default:
+              (*it_name) += " : " + pc->Props.at(1)->Value;
+          }
+          (*it_name) += " " + ((*it_type).isEmpty() ?
+          VHDL_SIGNAL_TYPE : (*it_type));
+        }
       }
     }
   }
@@ -1282,7 +1298,7 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
         SubParameter *pp;
         ID_Text *pid = (ID_Text*)pi;
         for(pp = pid->Parameter.first(); pp != 0; pp = pid->Parameter.next()) {
-          s = pp->Name;  // keep 'Name' unchanged
+          s = pp->Name; // keep 'Name' unchanged
           (*tstream) << " " << s.replace("=", "=\"") << '"';
         }
         break;
@@ -1300,62 +1316,62 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
     if (isVerilog) {
       // ..... digital subcircuit ...................................
       (*tstream) << "\nmodule Sub_" << Type << " ("
-		 << SubcircuitPortNames.join(", ") << ");\n";
+              << SubcircuitPortNames.join(", ") << ");\n";
 
       // subcircuit in/out connections
       if(!InPorts.isEmpty())
-	(*tstream) << "  input " << InPorts.join(", ") << ";\n";
+        (*tstream) << " input " << InPorts.join(", ") << ";\n";
       if(!OutPorts.isEmpty())
-	(*tstream) << "  output " << OutPorts.join(", ") << ";\n";
+        (*tstream) << " output " << OutPorts.join(", ") << ";\n";
       if(!InOutPorts.isEmpty())
-	(*tstream) << "  inout " << InOutPorts.join(", ") << ";\n";
+        (*tstream) << " inout " << InOutPorts.join(", ") << ";\n";
 
       // subcircuit connections
       if(!Signals.isEmpty()) {
-	QValueList<DigSignal> values = Signals.values();
-	QValueList<DigSignal>::iterator it;
-	for (it = values.begin(); it != values.end(); ++it) {
-	  (*tstream) << "  wire " << (*it).Name << ";\n";
-	}
+        Q3ValueList<DigSignal> values = Signals.values();
+        Q3ValueList<DigSignal>::iterator it;
+        for (it = values.begin(); it != values.end(); ++it) {
+          (*tstream) << " wire " << (*it).Name << ";\n";
+        }
       }
       (*tstream) << "\n";
 
       // subcircuit parameters
       for(pi = SymbolPaints.first(); pi != 0; pi = SymbolPaints.next())
-	if(pi->Name == ".ID ") {
-	  SubParameter *pp;
-	  ID_Text *pid = (ID_Text*)pi;
-	  if(pid->Parameter.first()) {
-	    for(pp = pid->Parameter.first(); pp != 0;) {
-	      s = pp->Name.section('=', 0,0);
-	      QString v = Verilog_Param(pp->Name.section('=', 1,1));
-	      (*tstream) << "  parameter " << s << " = " << v << ";\n";
-	      pp = pid->Parameter.next();
-	    }
-	    (*tstream) << "\n";
-	  }
-	  break;
-	}
+        if(pi->Name == ".ID ") {
+          SubParameter *pp;
+          ID_Text *pid = (ID_Text*)pi;
+          if(pid->Parameter.first()) {
+            for(pp = pid->Parameter.first(); pp != 0;) {
+              s = pp->Name.section('=', 0,0);
+              QString v = Verilog_Param(pp->Name.section('=', 1,1));
+              (*tstream) << " parameter " << s << " = " << v << ";\n";
+              pp = pid->Parameter.next();
+            }
+            (*tstream) << "\n";
+          }
+          break;
+        }
 
       // write all equations into netlist file
       for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-	if(pc->Model == "Eqn") {
-	  (*tstream) << pc->get_Verilog_Code(NumPorts);
-	}
+        if(pc->Model == "Eqn") {
+          (*tstream) << pc->get_Verilog_Code(NumPorts);
+        }
       }
 
       if(Signals.find("gnd") != Signals.end())
-	(*tstream) << "  assign gnd = 0;\n";  // should appear only once
+      (*tstream) << " assign gnd = 0;\n"; // should appear only once
 
       // write all components into netlist file
       for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-	if(pc->Model != "Eqn") {
-	  s = pc->get_Verilog_Code(NumPorts);
-	  if(s.at(0) == '') {
-	    ErrText->insert(s.mid(1));
-	  }
-	  else (*tstream) << s;
-	}
+        if(pc->Model != "Eqn") {
+          s = pc->get_Verilog_Code(NumPorts);
+          if(s.length()>0 && s.at(0) == '\xA7') {  //section symbol
+            ErrText->insert(s.mid(1));
+          }
+          else (*tstream) << s;
+        }
       }
 
       (*tstream) << "endmodule\n";
@@ -1363,66 +1379,66 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
       // ..... digital subcircuit ...................................
       (*tstream) << VHDL_LIBRARIES;
       (*tstream) << "entity Sub_" << Type << " is\n"
-		 << "  port ("
-		 << SubcircuitPortNames.join(";\n        ") << ");\n";
+                << " port ("
+                << SubcircuitPortNames.join(";\n ") << ");\n";
 
       for(pi = SymbolPaints.first(); pi != 0; pi = SymbolPaints.next())
-	if(pi->Name == ".ID ") {
-	  SubParameter *pp;
-	  ID_Text *pid = (ID_Text*)pi;
-	  if(pid->Parameter.first()) {
-	    (*tstream) << "  generic (";
-	    for(pp = pid->Parameter.first(); pp != 0;) {
-	      s = pp->Name;
-	      QString t = pp->Type.isEmpty() ? "real" : pp->Type;
-	      (*tstream) << s.replace("=", " : "+t+" := ");
-	      pp = pid->Parameter.next();
-	      if(pp) (*tstream) << ";\n           ";
-	    }
-	    (*tstream) << ");\n";
-	  }
-	  break;
-	}
+        if(pi->Name == ".ID ") {
+          SubParameter *pp;
+          ID_Text *pid = (ID_Text*)pi;
+          if(pid->Parameter.first()) {
+            (*tstream) << " generic (";
+            for(pp = pid->Parameter.first(); pp != 0;) {
+              s = pp->Name;
+              QString t = pp->Type.isEmpty() ? "real" : pp->Type;
+              (*tstream) << s.replace("=", " : "+t+" := ");
+              pp = pid->Parameter.next();
+              if(pp) (*tstream) << ";\n ";
+            }
+            (*tstream) << ");\n";
+          }
+          break;
+        }
 
       (*tstream) << "end entity;\n"
-		 << "use work.all;\n"
-		 << "architecture Arch_Sub_" << Type << " of Sub_" << Type
-		 << " is\n";
+                  << "use work.all;\n"
+                  << "architecture Arch_Sub_" << Type << " of Sub_" << Type
+                  << " is\n";
 
       if(!Signals.isEmpty()) {
-	QValueList<DigSignal> values = Signals.values();
-	QValueList<DigSignal>::iterator it;
-	for (it = values.begin(); it != values.end(); ++it) {
-	  (*tstream) << "  signal " << (*it).Name << " : " 
-		     << ((*it).Type.isEmpty() ? 
-			 VHDL_SIGNAL_TYPE : (*it).Type) << ";\n";
-	}
+        Q3ValueList<DigSignal> values = Signals.values();
+        Q3ValueList<DigSignal>::iterator it;
+        for (it = values.begin(); it != values.end(); ++it) {
+          (*tstream) << " signal " << (*it).Name << " : "
+          << ((*it).Type.isEmpty() ?
+          VHDL_SIGNAL_TYPE : (*it).Type) << ";\n";
+        }
       }
 
       // write all equations into netlist file
       for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-	if(pc->Model == "Eqn") {
-	  ErrText->insert(
-            QObject::tr("WARNING: Equations in \"%1\" are 'time' typed.").
-	    arg(pc->Name));
-	  (*tstream) << pc->get_VHDL_Code(NumPorts);
-	}
+        if(pc->Model == "Eqn") {
+          ErrText->insert(
+                      QObject::tr("WARNING: Equations in \"%1\" are 'time' typed.").
+          arg(pc->Name));
+          (*tstream) << pc->get_VHDL_Code(NumPorts);
+        }
       }
 
       (*tstream) << "begin\n";
 
       if(Signals.find("gnd") != Signals.end())
-	(*tstream) << "  gnd <= '0';\n";  // should appear only once
+      (*tstream) << " gnd <= '0';\n"; // should appear only once
 
       // write all components into netlist file
       for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-	if(pc->Model != "Eqn") {
-	  s = pc->get_VHDL_Code(NumPorts);
-	  if(s.at(0) == '') {
-	    ErrText->insert(s.mid(1));
-	  }
-	  else (*tstream) << s;
-	}
+        if(pc->Model != "Eqn") {
+            s = pc->get_VHDL_Code(NumPorts);
+            if(s.length()>0 && s.at(0) == '\xA7') {  //section symbol
+              ErrText->insert(s.mid(1));
+          }
+          else (*tstream) << s;
+        }
       }
 
       (*tstream) << "end architecture;\n";
@@ -1435,7 +1451,6 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
     delete tstream;
   }
 }
-
 // ---------------------------------------------------
 // Write the netlist as subcircuit to the text stream 'stream'.
 bool Schematic::createSubNetlist(QTextStream *stream, int& countInit,
@@ -1486,13 +1501,12 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
         }
         if(pc->Props.getFirst()->Value != "TimeList")
           isTruthTable = true;
-	if(pc->Props.getLast()->Value != "VHDL")
-	  isVerilog = true;
+	      if(pc->Props.getLast()->Value != "VHDL")
+	        isVerilog = true;
         allTypes |= isDigitalComponent;
-	isAnalog = false;
+	      isAnalog = false;
       }
       else allTypes |= isAnalogComponent;
-
       if((allTypes & isComponent) == isComponent) {
         ErrText->insert(
            QObject::tr("ERROR: Analog and digital simulations cannot be mixed."));
@@ -1561,16 +1575,16 @@ void Schematic::beginNetlistDigital(QTextStream& stream)
 {
   if (isVerilog) {
     stream << "module TestBench ();\n";
-    QValueList<DigSignal> values = Signals.values();
-    QValueList<DigSignal>::iterator it;
+    Q3ValueList<DigSignal> values = Signals.values();
+    Q3ValueList<DigSignal>::iterator it;
     for (it = values.begin(); it != values.end(); ++it) {
       stream << "  wire " << (*it).Name << ";\n";
     }
     stream << "\n";
   } else {
     stream << "architecture Arch_TestBench of TestBench is\n";
-    QValueList<DigSignal> values = Signals.values();
-    QValueList<DigSignal>::iterator it;
+    Q3ValueList<DigSignal> values = Signals.values();
+    Q3ValueList<DigSignal>::iterator it;
     for (it = values.begin(); it != values.end(); ++it) {
       stream << "  signal " << (*it).Name << " : "
 	     << ((*it).Type.isEmpty() ?
@@ -1635,7 +1649,9 @@ QString Schematic::createNetlist(QTextStream& stream, int NumPorts)
       } else {
 	s = pc->get_VHDL_Code(NumPorts);
       }
-      if(s.at(0) == '') return s;   // return error
+      if (s.length()>0 && s.at(0) == '\xA7'){
+          return s; // return error
+      }
     }
     stream << s;
   }
