@@ -18,18 +18,8 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-
-#include <qlabel.h>
-#include <qaction.h>
-#include <qpixmap.h>
-#include <qprinter.h>
-#include <qfileinfo.h>
-#include <qtabwidget.h>
-#include <qmessagebox.h>
-#include <qpaintdevicemetrics.h>
-#include <qfont.h>
-#include <qpopupmenu.h>
-#include <qsyntaxhighlighter.h>
+#include <QtGui>
+#include <QtCore>
 
 #include "main.h"
 #include "qucs.h"
@@ -39,14 +29,14 @@
 #include "components/verilogfile.h"
 #include "components/vafile.h"
 
-TextDoc::TextDoc(QucsApp *App_, const QString& Name_) : QucsDoc(App_, Name_)
+TextDoc::TextDoc(QucsApp *App_, const QString& Name_) : QucsDoc(App_, Name_), QTextEdit()
 {
   TextFont = QFont("Courier New");
   TextFont.setPointSize(QucsSettings.font.pointSize()-1);
   TextFont.setStyleHint(QFont::Courier);
   TextFont.setFixedPitch(true);
   setFont(TextFont);
-  setCurrentFont(TextFont);
+  //Removed, otherwise zoomIn/Out does not work setCurrentFont(TextFont);
 
   simulation = true;
   Library = "";
@@ -56,29 +46,29 @@ TextDoc::TextDoc(QucsApp *App_, const QString& Name_) : QucsDoc(App_, Name_)
 
   tmpPosX = tmpPosY = 1;  // set to 1 to trigger line highlighting
   Scale = (float)TextFont.pointSize();
-  setUndoDepth(QucsSettings.maxUndo);
+  //TODO (not supported) setUndoDepth(QucsSettings.maxUndo);
   setLanguage (Name_);
   QFileInfo Info (Name_);
-  
+
   if(App) {
-    if(Name_.isEmpty())
-      App->DocumentTab->addTab(this, QPixmap(empty_xpm),
-                            QObject::tr("untitled"));
-    else
-      App->DocumentTab->addTab(this, QPixmap(empty_xpm),
-                            Info.fileName());
-    // calls indirectly "becomeCurrent"
+    if(Name_.isEmpty()) {
+      App->DocumentTab->addTab(this, QPixmap(empty_xpm), QObject::tr("untitled"));
+      }
+    else {
+      App->DocumentTab->addTab(this, QPixmap(empty_xpm), Info.fileName());
+    }
     App->DocumentTab->setCurrentPage(App->DocumentTab->indexOf(this));
+
     viewport()->setFocus();
 
-    setWordWrap(QTextEdit::NoWrap);
+    setWordWrapMode(QTextOption::NoWrap);
     setPaletteBackgroundColor(QucsSettings.BGColor);
     connect(this, SIGNAL(textChanged()), SLOT(slotSetChanged()));
-    connect(this, SIGNAL(cursorPositionChanged(int, int)),
-            SLOT(slotCursorPosChanged(int, int)));
+    connect(this, SIGNAL(cursorPositionChanged()),
+            SLOT(slotCursorPosChanged()));
 
     syntaxHighlight = new SyntaxHighlighter(this);
-    syntaxHighlight->setLanguage (language);
+    syntaxHighlight->setLanguage(language);
   }
 }
 
@@ -117,10 +107,10 @@ void TextDoc::setLanguage (int lang)
 bool TextDoc::saveSettings (void)
 {
   QFile file (DocName + ".cfg");
-  if (!file.open (IO_WriteOnly))
+  if (!file.open (QIODevice::WriteOnly))
     return false;
 
-  QTextStream stream (&file);
+  Q3TextStream stream (&file);
   stream << "Textfile settings file, Qucs " PACKAGE_VERSION "\n"
 	 << "Simulation=" << simulation << "\n"
 	 << "Duration=" << SimTime << "\n"
@@ -142,10 +132,10 @@ bool TextDoc::saveSettings (void)
 bool TextDoc::loadSettings (void)
 {
   QFile file (DocName + ".cfg");
-  if (!file.open (IO_ReadOnly))
+  if (!file.open (QIODevice::ReadOnly))
     return false;
 
-  QTextStream stream (&file);
+  Q3TextStream stream (&file);
   QString Line, Setting;
 
   bool ok;
@@ -199,8 +189,7 @@ void TextDoc::setName (const QString& Name_)
 void TextDoc::becomeCurrent (bool)
 {
   int x, y;
-  getCursorPosition (&x, &y);
-  slotCursorPosChanged (x, y);
+  slotCursorPosChanged();
   viewport()->setFocus ();
 
   if (isUndoAvailable ())
@@ -241,15 +230,21 @@ void TextDoc::becomeCurrent (bool)
 }
 
 // ---------------------------------------------------
-void TextDoc::slotCursorPosChanged(int x, int y)
+void TextDoc::slotCursorPosChanged()
 {
-  if(tmpPosX > x)
-    clearParagraphBackground(tmpPosX);
-  else
-    for(int z=tmpPosX; z<x; z++)
-      clearParagraphBackground(z);
-  if(tmpPosX != x)
-    setParagraphBackgroundColor(x, QColor(240, 240, 255));
+  QTextCursor pos = textCursor();
+  int x = pos.blockNumber();
+  int y = pos.columnNumber();
+
+  // TODO This seems to be difficult; maybe http://pepper.troll.no/s60prereleases/doc/widgets-codeeditor.html
+
+  //if(tmpPosX > x)
+    //TODO clearParagraphBackground(tmpPosX);
+  //else
+    //for(int z=tmpPosX; z<x; z++)
+      //TODO clearParagraphBackground(z);
+  //if(tmpPosX != x)
+    //TODO setParagraphBackgroundColor(x, QColor(240, 240, 255));
   App->printCursorPosition(x+1, y+1);
   tmpPosX = x;
   tmpPosY = y;
@@ -272,9 +267,10 @@ void TextDoc::slotSetChanged()
 }
 
 // ---------------------------------------------------
-QPopupMenu *TextDoc::createPopupMenu( const QPoint &pos )
+QMenu *TextDoc::createStandardContextMenu( const QPoint &pos )
 {
-   QPopupMenu *popup = QTextEdit::createPopupMenu( pos );
+  QMenu *popup = QTextEdit::createStandardContextMenu(pos);
+
    if (language != LANG_OCTAVE) {
      App->fileSettings->addTo(popup);
    }
@@ -284,8 +280,9 @@ QPopupMenu *TextDoc::createPopupMenu( const QPoint &pos )
 // ---------------------------------------------------
 bool TextDoc::load ()
 {
+  
   QFile file (DocName);
-  if (!file.open (IO_ReadOnly))
+  if (!file.open (QIODevice::ReadOnly))
     return false;
   setLanguage (DocName);
 
@@ -295,7 +292,6 @@ bool TextDoc::load ()
   slotSetChanged ();
   file.close ();
   lastSaved = QDateTime::currentDateTime ();
-
   loadSettings ();
   SimOpenDpl = simulation ? true : false;
   return true;
@@ -307,11 +303,11 @@ int TextDoc::save ()
   saveSettings ();
 
   QFile file (DocName);
-  if (!file.open (IO_WriteOnly))
+  if (!file.open (QIODevice::WriteOnly))
     return -1;
   setLanguage (DocName);
 
-  QTextStream stream (&file);
+  Q3TextStream stream (&file);
   stream << text ();
   setModified (false);
   slotSetChanged ();
@@ -322,84 +318,28 @@ int TextDoc::save ()
   return 0;
 }
 
-// -----------------------------------------------------------
-void TextDoc::print(QPrinter *Printer, QPainter *Painter, bool printAll, bool)
-{
-  Painter->setFont(TextFont);
-
-  sync();   // formatting whole text
-
-  QPaintDeviceMetrics smetrics(QPainter(this).device());
-  QPaintDeviceMetrics pmetrics(Painter->device());
-  int margin  = 54;    // margin at each side (unit is point)
-  int marginX = margin * pmetrics.logicalDpiX() / smetrics.logicalDpiX();
-  int marginY = margin * pmetrics.logicalDpiY() / smetrics.logicalDpiY();
-  QRect printArea(
-        marginX, marginY, pmetrics.width() - 2*marginX,
-        pmetrics.height() - 2*marginY - Painter->fontMetrics().lineSpacing());
-
-  int linesPerPage = printArea.height() / Painter->fontMetrics().lineSpacing();
-
-  int PageCount, PageNo = 1;
-  QString s, printText;
-  if(printAll) {
-    printText = text();
-    PageCount = paragraphs();
-  }
-  else {
-    int line1, col1, line2, col2;
-    printText = selectedText();
-    getSelection(&line1, &col1, &line2, &col2);
-    if(line1 < 0) {
-      QMessageBox::critical(this, tr("Error"), tr("There is no selection!"));
-      return;
-    }
-    PageCount = line2 - line1 + 1;
-  }
-  PageCount = (PageCount + linesPerPage - 1) / linesPerPage;
-  
-  for(;;) {
-    if(Printer->aborted())
-      break;
-    Painter->drawText(printArea, 0, printText.section('\n', 0, linesPerPage-1));
-    printText = printText.section('\n', linesPerPage);
-
-    s = tr("Page %1 of %2").arg(PageNo).arg(PageCount);
-    Painter->drawText(printArea.right() - Painter->fontMetrics().width(s),
-               printArea.bottom() + Painter->fontMetrics().lineSpacing(), s);
-    if(printText.isEmpty())
-      break;
-    Printer->newPage();
-    PageNo++;
-  }
-}
 
 // ---------------------------------------------------
 float TextDoc::zoomBy(float s)
 {
-  if(s < 1.0f) s = -1.0f/s;
-  Scale += s;
-  if(Scale > 40.0f) Scale = 40.0f;
-  if(Scale <  4.0f) Scale =  4.0f;
-  zoomTo((int)(Scale+0.5f));
+  if(s == 2.0) {
+    this->zoomIn(2);
+  }
+  else {
+    this->zoomOut(2); 
+  }
   return Scale;
 }
 
-// ---------------------------------------------------
-void TextDoc::showAll()
-{
-  sync();
-  Scale *= float(visibleHeight()) / float(contentsHeight());
-  if(Scale > 40.0f) Scale = 40.0f;
-  if(Scale <  4.0f) Scale =  4.0f;
-  zoomTo((int)(Scale+0.5f));
-}
 
 // ---------------------------------------------------
 void TextDoc::showNoZoom()
 {
-  Scale = (float)TextFont.pointSize();
-  zoomTo(TextFont.pointSize());
+  TextFont = QFont("Courier New");
+  TextFont.setPointSize(QucsSettings.font.pointSize()-1);
+  TextFont.setStyleHint(QFont::Courier);
+  TextFont.setFixedPitch(true);
+  setFont(TextFont);
 }
 
 // ---------------------------------------------------
