@@ -18,7 +18,9 @@
 #ifndef TEXTDOC_H
 #define TEXTDOC_H
 
-#include <qtextedit.h>
+
+#include <QTextEdit>
+#include <q3textedit.h>
 #include <qfont.h>
 
 #include "qucsdoc.h"
@@ -47,9 +49,7 @@ public:
   void  setName (const QString&);
   bool  load ();
   int   save ();
-  void  print (QPrinter*, QPainter*, bool, bool);
   float zoomBy (float);
-  void  showAll ();
   void  showNoZoom ();
   void  becomeCurrent (bool);
   bool  loadSimulationTime (QString&);
@@ -76,10 +76,10 @@ public:
   bool loadSettings (void);
   bool saveSettings (void);
 
-  QPopupMenu * createPopupMenu (const QPoint&);
+  QMenu* createStandardContextMenu(const QPoint&);
 
 public slots:
-  void slotCursorPosChanged (int, int);
+  void slotCursorPosChanged ();
   void slotSetChanged ();
 
 private:
